#define VM_HANDLERS(_) \
	_(0, ZEND_NOP_SPEC) \
	_(1, ZEND_ADD_SPEC_CONST_CONST) \
	_(2, ZEND_ADD_SPEC_CONST_TMPVAR) \
	_(3, ZEND_ADD_SPEC_CONST_TMPVAR) \
	_(5, ZEND_ADD_SPEC_CONST_CV) \
	_(6, ZEND_ADD_SPEC_TMPVAR_CONST) \
	_(7, ZEND_ADD_SPEC_TMPVAR_TMPVAR) \
	_(8, ZEND_ADD_SPEC_TMPVAR_TMPVAR) \
	_(10, ZEND_ADD_SPEC_TMPVAR_CV) \
	_(11, ZEND_ADD_SPEC_TMPVAR_CONST) \
	_(12, ZEND_ADD_SPEC_TMPVAR_TMPVAR) \
	_(13, ZEND_ADD_SPEC_TMPVAR_TMPVAR) \
	_(15, ZEND_ADD_SPEC_TMPVAR_CV) \
	_(21, ZEND_ADD_SPEC_CV_CONST) \
	_(22, ZEND_ADD_SPEC_CV_TMPVAR) \
	_(23, ZEND_ADD_SPEC_CV_TMPVAR) \
	_(25, ZEND_ADD_SPEC_CV_CV) \
	_(26, ZEND_SUB_SPEC_CONST_CONST) \
	_(27, ZEND_SUB_SPEC_CONST_TMPVAR) \
	_(28, ZEND_SUB_SPEC_CONST_TMPVAR) \
	_(30, ZEND_SUB_SPEC_CONST_CV) \
	_(31, ZEND_SUB_SPEC_TMPVAR_CONST) \
	_(32, ZEND_SUB_SPEC_TMPVAR_TMPVAR) \
	_(33, ZEND_SUB_SPEC_TMPVAR_TMPVAR) \
	_(35, ZEND_SUB_SPEC_TMPVAR_CV) \
	_(36, ZEND_SUB_SPEC_TMPVAR_CONST) \
	_(37, ZEND_SUB_SPEC_TMPVAR_TMPVAR) \
	_(38, ZEND_SUB_SPEC_TMPVAR_TMPVAR) \
	_(40, ZEND_SUB_SPEC_TMPVAR_CV) \
	_(46, ZEND_SUB_SPEC_CV_CONST) \
	_(47, ZEND_SUB_SPEC_CV_TMPVAR) \
	_(48, ZEND_SUB_SPEC_CV_TMPVAR) \
	_(50, ZEND_SUB_SPEC_CV_CV) \
	_(51, ZEND_MUL_SPEC_CONST_CONST) \
	_(56, ZEND_MUL_SPEC_TMPVAR_CONST) \
	_(57, ZEND_MUL_SPEC_TMPVAR_TMPVAR) \
	_(58, ZEND_MUL_SPEC_TMPVAR_TMPVAR) \
	_(61, ZEND_MUL_SPEC_TMPVAR_CONST) \
	_(62, ZEND_MUL_SPEC_TMPVAR_TMPVAR) \
	_(63, ZEND_MUL_SPEC_TMPVAR_TMPVAR) \
	_(71, ZEND_MUL_SPEC_CV_CONST) \
	_(72, ZEND_MUL_SPEC_CV_TMPVAR) \
	_(73, ZEND_MUL_SPEC_CV_TMPVAR) \
	_(75, ZEND_MUL_SPEC_CV_CV) \
	_(76, ZEND_DIV_SPEC_CONST_CONST) \
	_(77, ZEND_DIV_SPEC_CONST_TMPVAR) \
	_(78, ZEND_DIV_SPEC_CONST_TMPVAR) \
	_(80, ZEND_DIV_SPEC_CONST_CV) \
	_(81, ZEND_DIV_SPEC_TMPVAR_CONST) \
	_(82, ZEND_DIV_SPEC_TMPVAR_TMPVAR) \
	_(83, ZEND_DIV_SPEC_TMPVAR_TMPVAR) \
	_(85, ZEND_DIV_SPEC_TMPVAR_CV) \
	_(86, ZEND_DIV_SPEC_TMPVAR_CONST) \
	_(87, ZEND_DIV_SPEC_TMPVAR_TMPVAR) \
	_(88, ZEND_DIV_SPEC_TMPVAR_TMPVAR) \
	_(90, ZEND_DIV_SPEC_TMPVAR_CV) \
	_(96, ZEND_DIV_SPEC_CV_CONST) \
	_(97, ZEND_DIV_SPEC_CV_TMPVAR) \
	_(98, ZEND_DIV_SPEC_CV_TMPVAR) \
	_(100, ZEND_DIV_SPEC_CV_CV) \
	_(101, ZEND_MOD_SPEC_CONST_CONST) \
	_(102, ZEND_MOD_SPEC_CONST_TMPVAR) \
	_(103, ZEND_MOD_SPEC_CONST_TMPVAR) \
	_(105, ZEND_MOD_SPEC_CONST_CV) \
	_(106, ZEND_MOD_SPEC_TMPVAR_CONST) \
	_(107, ZEND_MOD_SPEC_TMPVAR_TMPVAR) \
	_(108, ZEND_MOD_SPEC_TMPVAR_TMPVAR) \
	_(110, ZEND_MOD_SPEC_TMPVAR_CV) \
	_(111, ZEND_MOD_SPEC_TMPVAR_CONST) \
	_(112, ZEND_MOD_SPEC_TMPVAR_TMPVAR) \
	_(113, ZEND_MOD_SPEC_TMPVAR_TMPVAR) \
	_(115, ZEND_MOD_SPEC_TMPVAR_CV) \
	_(121, ZEND_MOD_SPEC_CV_CONST) \
	_(122, ZEND_MOD_SPEC_CV_TMPVAR) \
	_(123, ZEND_MOD_SPEC_CV_TMPVAR) \
	_(125, ZEND_MOD_SPEC_CV_CV) \
	_(126, ZEND_SL_SPEC_CONST_CONST) \
	_(127, ZEND_SL_SPEC_CONST_TMPVAR) \
	_(128, ZEND_SL_SPEC_CONST_TMPVAR) \
	_(130, ZEND_SL_SPEC_CONST_CV) \
	_(131, ZEND_SL_SPEC_TMPVAR_CONST) \
	_(132, ZEND_SL_SPEC_TMPVAR_TMPVAR) \
	_(133, ZEND_SL_SPEC_TMPVAR_TMPVAR) \
	_(135, ZEND_SL_SPEC_TMPVAR_CV) \
	_(136, ZEND_SL_SPEC_TMPVAR_CONST) \
	_(137, ZEND_SL_SPEC_TMPVAR_TMPVAR) \
	_(138, ZEND_SL_SPEC_TMPVAR_TMPVAR) \
	_(140, ZEND_SL_SPEC_TMPVAR_CV) \
	_(146, ZEND_SL_SPEC_CV_CONST) \
	_(147, ZEND_SL_SPEC_CV_TMPVAR) \
	_(148, ZEND_SL_SPEC_CV_TMPVAR) \
	_(150, ZEND_SL_SPEC_CV_CV) \
	_(151, ZEND_SR_SPEC_CONST_CONST) \
	_(152, ZEND_SR_SPEC_CONST_TMPVAR) \
	_(153, ZEND_SR_SPEC_CONST_TMPVAR) \
	_(155, ZEND_SR_SPEC_CONST_CV) \
	_(156, ZEND_SR_SPEC_TMPVAR_CONST) \
	_(157, ZEND_SR_SPEC_TMPVAR_TMPVAR) \
	_(158, ZEND_SR_SPEC_TMPVAR_TMPVAR) \
	_(160, ZEND_SR_SPEC_TMPVAR_CV) \
	_(161, ZEND_SR_SPEC_TMPVAR_CONST) \
	_(162, ZEND_SR_SPEC_TMPVAR_TMPVAR) \
	_(163, ZEND_SR_SPEC_TMPVAR_TMPVAR) \
	_(165, ZEND_SR_SPEC_TMPVAR_CV) \
	_(171, ZEND_SR_SPEC_CV_CONST) \
	_(172, ZEND_SR_SPEC_CV_TMPVAR) \
	_(173, ZEND_SR_SPEC_CV_TMPVAR) \
	_(175, ZEND_SR_SPEC_CV_CV) \
	_(177, ZEND_CONCAT_SPEC_CONST_TMPVAR) \
	_(178, ZEND_CONCAT_SPEC_CONST_TMPVAR) \
	_(180, ZEND_CONCAT_SPEC_CONST_CV) \
	_(181, ZEND_CONCAT_SPEC_TMPVAR_CONST) \
	_(182, ZEND_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(183, ZEND_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(185, ZEND_CONCAT_SPEC_TMPVAR_CV) \
	_(186, ZEND_CONCAT_SPEC_TMPVAR_CONST) \
	_(187, ZEND_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(188, ZEND_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(190, ZEND_CONCAT_SPEC_TMPVAR_CV) \
	_(196, ZEND_CONCAT_SPEC_CV_CONST) \
	_(197, ZEND_CONCAT_SPEC_CV_TMPVAR) \
	_(198, ZEND_CONCAT_SPEC_CV_TMPVAR) \
	_(200, ZEND_CONCAT_SPEC_CV_CV) \
	_(201, ZEND_BW_OR_SPEC_CONST_CONST) \
	_(206, ZEND_BW_OR_SPEC_TMPVAR_CONST) \
	_(207, ZEND_BW_OR_SPEC_TMPVAR_TMPVAR) \
	_(208, ZEND_BW_OR_SPEC_TMPVAR_TMPVAR) \
	_(211, ZEND_BW_OR_SPEC_TMPVAR_CONST) \
	_(212, ZEND_BW_OR_SPEC_TMPVAR_TMPVAR) \
	_(213, ZEND_BW_OR_SPEC_TMPVAR_TMPVAR) \
	_(221, ZEND_BW_OR_SPEC_CV_CONST) \
	_(222, ZEND_BW_OR_SPEC_CV_TMPVAR) \
	_(223, ZEND_BW_OR_SPEC_CV_TMPVAR) \
	_(225, ZEND_BW_OR_SPEC_CV_CV) \
	_(226, ZEND_BW_AND_SPEC_CONST_CONST) \
	_(231, ZEND_BW_AND_SPEC_TMPVAR_CONST) \
	_(232, ZEND_BW_AND_SPEC_TMPVAR_TMPVAR) \
	_(233, ZEND_BW_AND_SPEC_TMPVAR_TMPVAR) \
	_(236, ZEND_BW_AND_SPEC_TMPVAR_CONST) \
	_(237, ZEND_BW_AND_SPEC_TMPVAR_TMPVAR) \
	_(238, ZEND_BW_AND_SPEC_TMPVAR_TMPVAR) \
	_(246, ZEND_BW_AND_SPEC_CV_CONST) \
	_(247, ZEND_BW_AND_SPEC_CV_TMPVAR) \
	_(248, ZEND_BW_AND_SPEC_CV_TMPVAR) \
	_(250, ZEND_BW_AND_SPEC_CV_CV) \
	_(251, ZEND_BW_XOR_SPEC_CONST_CONST) \
	_(256, ZEND_BW_XOR_SPEC_TMPVAR_CONST) \
	_(257, ZEND_BW_XOR_SPEC_TMPVAR_TMPVAR) \
	_(258, ZEND_BW_XOR_SPEC_TMPVAR_TMPVAR) \
	_(261, ZEND_BW_XOR_SPEC_TMPVAR_CONST) \
	_(262, ZEND_BW_XOR_SPEC_TMPVAR_TMPVAR) \
	_(263, ZEND_BW_XOR_SPEC_TMPVAR_TMPVAR) \
	_(271, ZEND_BW_XOR_SPEC_CV_CONST) \
	_(272, ZEND_BW_XOR_SPEC_CV_TMPVAR) \
	_(273, ZEND_BW_XOR_SPEC_CV_TMPVAR) \
	_(275, ZEND_BW_XOR_SPEC_CV_CV) \
	_(276, ZEND_BW_NOT_SPEC_CONST) \
	_(277, ZEND_BW_NOT_SPEC_TMPVAR) \
	_(278, ZEND_BW_NOT_SPEC_TMPVAR) \
	_(280, ZEND_BW_NOT_SPEC_CV) \
	_(281, ZEND_BOOL_NOT_SPEC_CONST) \
	_(282, ZEND_BOOL_NOT_SPEC_TMPVAR) \
	_(283, ZEND_BOOL_NOT_SPEC_TMPVAR) \
	_(285, ZEND_BOOL_NOT_SPEC_CV) \
	_(286, ZEND_BOOL_XOR_SPEC_CONST_CONST) \
	_(291, ZEND_BOOL_XOR_SPEC_TMPVAR_CONST) \
	_(292, ZEND_BOOL_XOR_SPEC_TMPVAR_TMPVAR) \
	_(293, ZEND_BOOL_XOR_SPEC_TMPVAR_TMPVAR) \
	_(296, ZEND_BOOL_XOR_SPEC_TMPVAR_CONST) \
	_(297, ZEND_BOOL_XOR_SPEC_TMPVAR_TMPVAR) \
	_(298, ZEND_BOOL_XOR_SPEC_TMPVAR_TMPVAR) \
	_(306, ZEND_BOOL_XOR_SPEC_CV_CONST) \
	_(307, ZEND_BOOL_XOR_SPEC_CV_TMPVAR) \
	_(308, ZEND_BOOL_XOR_SPEC_CV_TMPVAR) \
	_(310, ZEND_BOOL_XOR_SPEC_CV_CV) \
	_(311, ZEND_IS_IDENTICAL_SPEC_CONST_CONST) \
	_(316, ZEND_IS_IDENTICAL_SPEC_TMP_CONST) \
	_(317, ZEND_IS_IDENTICAL_SPEC_TMP_TMP) \
	_(321, ZEND_IS_IDENTICAL_SPEC_VAR_CONST) \
	_(322, ZEND_IS_IDENTICAL_SPEC_VAR_TMP) \
	_(323, ZEND_IS_IDENTICAL_SPEC_VAR_VAR) \
	_(331, ZEND_IS_IDENTICAL_SPEC_CV_CONST) \
	_(332, ZEND_IS_IDENTICAL_SPEC_CV_TMP) \
	_(333, ZEND_IS_IDENTICAL_SPEC_CV_VAR) \
	_(335, ZEND_IS_IDENTICAL_SPEC_CV_CV) \
	_(336, ZEND_IS_NOT_IDENTICAL_SPEC_CONST_CONST) \
	_(341, ZEND_IS_NOT_IDENTICAL_SPEC_TMP_CONST) \
	_(342, ZEND_IS_NOT_IDENTICAL_SPEC_TMP_TMP) \
	_(346, ZEND_IS_NOT_IDENTICAL_SPEC_VAR_CONST) \
	_(347, ZEND_IS_NOT_IDENTICAL_SPEC_VAR_TMP) \
	_(348, ZEND_IS_NOT_IDENTICAL_SPEC_VAR_VAR) \
	_(356, ZEND_IS_NOT_IDENTICAL_SPEC_CV_CONST) \
	_(357, ZEND_IS_NOT_IDENTICAL_SPEC_CV_TMP) \
	_(358, ZEND_IS_NOT_IDENTICAL_SPEC_CV_VAR) \
	_(360, ZEND_IS_NOT_IDENTICAL_SPEC_CV_CV) \
	_(361, ZEND_IS_EQUAL_SPEC_CONST_CONST) \
	_(366, ZEND_IS_EQUAL_SPEC_TMPVAR_CONST) \
	_(367, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(368, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(371, ZEND_IS_EQUAL_SPEC_TMPVAR_CONST) \
	_(372, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(373, ZEND_IS_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(381, ZEND_IS_EQUAL_SPEC_CV_CONST) \
	_(382, ZEND_IS_EQUAL_SPEC_CV_TMPVAR) \
	_(383, ZEND_IS_EQUAL_SPEC_CV_TMPVAR) \
	_(385, ZEND_IS_EQUAL_SPEC_CV_CV) \
	_(386, ZEND_IS_NOT_EQUAL_SPEC_CONST_CONST) \
	_(391, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_CONST) \
	_(392, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(393, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(396, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_CONST) \
	_(397, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(398, ZEND_IS_NOT_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(406, ZEND_IS_NOT_EQUAL_SPEC_CV_CONST) \
	_(407, ZEND_IS_NOT_EQUAL_SPEC_CV_TMPVAR) \
	_(408, ZEND_IS_NOT_EQUAL_SPEC_CV_TMPVAR) \
	_(410, ZEND_IS_NOT_EQUAL_SPEC_CV_CV) \
	_(411, ZEND_IS_SMALLER_SPEC_CONST_CONST) \
	_(412, ZEND_IS_SMALLER_SPEC_CONST_TMPVAR) \
	_(413, ZEND_IS_SMALLER_SPEC_CONST_TMPVAR) \
	_(415, ZEND_IS_SMALLER_SPEC_CONST_CV) \
	_(416, ZEND_IS_SMALLER_SPEC_TMPVAR_CONST) \
	_(417, ZEND_IS_SMALLER_SPEC_TMPVAR_TMPVAR) \
	_(418, ZEND_IS_SMALLER_SPEC_TMPVAR_TMPVAR) \
	_(420, ZEND_IS_SMALLER_SPEC_TMPVAR_CV) \
	_(421, ZEND_IS_SMALLER_SPEC_TMPVAR_CONST) \
	_(422, ZEND_IS_SMALLER_SPEC_TMPVAR_TMPVAR) \
	_(423, ZEND_IS_SMALLER_SPEC_TMPVAR_TMPVAR) \
	_(425, ZEND_IS_SMALLER_SPEC_TMPVAR_CV) \
	_(431, ZEND_IS_SMALLER_SPEC_CV_CONST) \
	_(432, ZEND_IS_SMALLER_SPEC_CV_TMPVAR) \
	_(433, ZEND_IS_SMALLER_SPEC_CV_TMPVAR) \
	_(435, ZEND_IS_SMALLER_SPEC_CV_CV) \
	_(436, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_CONST) \
	_(437, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_TMPVAR) \
	_(438, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_TMPVAR) \
	_(440, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CONST_CV) \
	_(441, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVAR_CONST) \
	_(442, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(443, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(445, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVAR_CV) \
	_(446, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVAR_CONST) \
	_(447, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(448, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVAR_TMPVAR) \
	_(450, ZEND_IS_SMALLER_OR_EQUAL_SPEC_TMPVAR_CV) \
	_(456, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CV_CONST) \
	_(457, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CV_TMPVAR) \
	_(458, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CV_TMPVAR) \
	_(460, ZEND_IS_SMALLER_OR_EQUAL_SPEC_CV_CV) \
	_(461, ZEND_CAST_SPEC_CONST) \
	_(462, ZEND_CAST_SPEC_TMP) \
	_(463, ZEND_CAST_SPEC_VAR) \
	_(465, ZEND_CAST_SPEC_CV) \
	_(466, ZEND_QM_ASSIGN_SPEC_CONST) \
	_(467, ZEND_QM_ASSIGN_SPEC_TMP) \
	_(468, ZEND_QM_ASSIGN_SPEC_VAR) \
	_(470, ZEND_QM_ASSIGN_SPEC_CV) \
	_(501, ZEND_ASSIGN_ADD_SPEC_VAR_CONST) \
	_(502, ZEND_ASSIGN_ADD_SPEC_VAR_CONST_DIM) \
	_(503, ZEND_ASSIGN_ADD_SPEC_VAR_CONST_OBJ) \
	_(504, ZEND_ASSIGN_ADD_SPEC_VAR_TMPVAR) \
	_(505, ZEND_ASSIGN_ADD_SPEC_VAR_TMPVAR_DIM) \
	_(506, ZEND_ASSIGN_ADD_SPEC_VAR_TMPVAR_OBJ) \
	_(507, ZEND_ASSIGN_ADD_SPEC_VAR_TMPVAR) \
	_(508, ZEND_ASSIGN_ADD_SPEC_VAR_TMPVAR_DIM) \
	_(509, ZEND_ASSIGN_ADD_SPEC_VAR_TMPVAR_OBJ) \
	_(511, ZEND_ASSIGN_ADD_SPEC_VAR_UNUSED_DIM) \
	_(513, ZEND_ASSIGN_ADD_SPEC_VAR_CV) \
	_(514, ZEND_ASSIGN_ADD_SPEC_VAR_CV_DIM) \
	_(515, ZEND_ASSIGN_ADD_SPEC_VAR_CV_OBJ) \
	_(518, ZEND_ASSIGN_ADD_SPEC_UNUSED_CONST_OBJ) \
	_(521, ZEND_ASSIGN_ADD_SPEC_UNUSED_TMPVAR_OBJ) \
	_(524, ZEND_ASSIGN_ADD_SPEC_UNUSED_TMPVAR_OBJ) \
	_(530, ZEND_ASSIGN_ADD_SPEC_UNUSED_CV_OBJ) \
	_(531, ZEND_ASSIGN_ADD_SPEC_CV_CONST) \
	_(532, ZEND_ASSIGN_ADD_SPEC_CV_CONST_DIM) \
	_(533, ZEND_ASSIGN_ADD_SPEC_CV_CONST_OBJ) \
	_(534, ZEND_ASSIGN_ADD_SPEC_CV_TMPVAR) \
	_(535, ZEND_ASSIGN_ADD_SPEC_CV_TMPVAR_DIM) \
	_(536, ZEND_ASSIGN_ADD_SPEC_CV_TMPVAR_OBJ) \
	_(537, ZEND_ASSIGN_ADD_SPEC_CV_TMPVAR) \
	_(538, ZEND_ASSIGN_ADD_SPEC_CV_TMPVAR_DIM) \
	_(539, ZEND_ASSIGN_ADD_SPEC_CV_TMPVAR_OBJ) \
	_(541, ZEND_ASSIGN_ADD_SPEC_CV_UNUSED_DIM) \
	_(543, ZEND_ASSIGN_ADD_SPEC_CV_CV) \
	_(544, ZEND_ASSIGN_ADD_SPEC_CV_CV_DIM) \
	_(545, ZEND_ASSIGN_ADD_SPEC_CV_CV_OBJ) \
	_(576, ZEND_ASSIGN_SUB_SPEC_VAR_CONST) \
	_(577, ZEND_ASSIGN_SUB_SPEC_VAR_CONST_DIM) \
	_(578, ZEND_ASSIGN_SUB_SPEC_VAR_CONST_OBJ) \
	_(579, ZEND_ASSIGN_SUB_SPEC_VAR_TMPVAR) \
	_(580, ZEND_ASSIGN_SUB_SPEC_VAR_TMPVAR_DIM) \
	_(581, ZEND_ASSIGN_SUB_SPEC_VAR_TMPVAR_OBJ) \
	_(582, ZEND_ASSIGN_SUB_SPEC_VAR_TMPVAR) \
	_(583, ZEND_ASSIGN_SUB_SPEC_VAR_TMPVAR_DIM) \
	_(584, ZEND_ASSIGN_SUB_SPEC_VAR_TMPVAR_OBJ) \
	_(586, ZEND_ASSIGN_SUB_SPEC_VAR_UNUSED_DIM) \
	_(588, ZEND_ASSIGN_SUB_SPEC_VAR_CV) \
	_(589, ZEND_ASSIGN_SUB_SPEC_VAR_CV_DIM) \
	_(590, ZEND_ASSIGN_SUB_SPEC_VAR_CV_OBJ) \
	_(593, ZEND_ASSIGN_SUB_SPEC_UNUSED_CONST_OBJ) \
	_(596, ZEND_ASSIGN_SUB_SPEC_UNUSED_TMPVAR_OBJ) \
	_(599, ZEND_ASSIGN_SUB_SPEC_UNUSED_TMPVAR_OBJ) \
	_(605, ZEND_ASSIGN_SUB_SPEC_UNUSED_CV_OBJ) \
	_(606, ZEND_ASSIGN_SUB_SPEC_CV_CONST) \
	_(607, ZEND_ASSIGN_SUB_SPEC_CV_CONST_DIM) \
	_(608, ZEND_ASSIGN_SUB_SPEC_CV_CONST_OBJ) \
	_(609, ZEND_ASSIGN_SUB_SPEC_CV_TMPVAR) \
	_(610, ZEND_ASSIGN_SUB_SPEC_CV_TMPVAR_DIM) \
	_(611, ZEND_ASSIGN_SUB_SPEC_CV_TMPVAR_OBJ) \
	_(612, ZEND_ASSIGN_SUB_SPEC_CV_TMPVAR) \
	_(613, ZEND_ASSIGN_SUB_SPEC_CV_TMPVAR_DIM) \
	_(614, ZEND_ASSIGN_SUB_SPEC_CV_TMPVAR_OBJ) \
	_(616, ZEND_ASSIGN_SUB_SPEC_CV_UNUSED_DIM) \
	_(618, ZEND_ASSIGN_SUB_SPEC_CV_CV) \
	_(619, ZEND_ASSIGN_SUB_SPEC_CV_CV_DIM) \
	_(620, ZEND_ASSIGN_SUB_SPEC_CV_CV_OBJ) \
	_(651, ZEND_ASSIGN_MUL_SPEC_VAR_CONST) \
	_(652, ZEND_ASSIGN_MUL_SPEC_VAR_CONST_DIM) \
	_(653, ZEND_ASSIGN_MUL_SPEC_VAR_CONST_OBJ) \
	_(654, ZEND_ASSIGN_MUL_SPEC_VAR_TMPVAR) \
	_(655, ZEND_ASSIGN_MUL_SPEC_VAR_TMPVAR_DIM) \
	_(656, ZEND_ASSIGN_MUL_SPEC_VAR_TMPVAR_OBJ) \
	_(657, ZEND_ASSIGN_MUL_SPEC_VAR_TMPVAR) \
	_(658, ZEND_ASSIGN_MUL_SPEC_VAR_TMPVAR_DIM) \
	_(659, ZEND_ASSIGN_MUL_SPEC_VAR_TMPVAR_OBJ) \
	_(661, ZEND_ASSIGN_MUL_SPEC_VAR_UNUSED_DIM) \
	_(663, ZEND_ASSIGN_MUL_SPEC_VAR_CV) \
	_(664, ZEND_ASSIGN_MUL_SPEC_VAR_CV_DIM) \
	_(665, ZEND_ASSIGN_MUL_SPEC_VAR_CV_OBJ) \
	_(668, ZEND_ASSIGN_MUL_SPEC_UNUSED_CONST_OBJ) \
	_(671, ZEND_ASSIGN_MUL_SPEC_UNUSED_TMPVAR_OBJ) \
	_(674, ZEND_ASSIGN_MUL_SPEC_UNUSED_TMPVAR_OBJ) \
	_(680, ZEND_ASSIGN_MUL_SPEC_UNUSED_CV_OBJ) \
	_(681, ZEND_ASSIGN_MUL_SPEC_CV_CONST) \
	_(682, ZEND_ASSIGN_MUL_SPEC_CV_CONST_DIM) \
	_(683, ZEND_ASSIGN_MUL_SPEC_CV_CONST_OBJ) \
	_(684, ZEND_ASSIGN_MUL_SPEC_CV_TMPVAR) \
	_(685, ZEND_ASSIGN_MUL_SPEC_CV_TMPVAR_DIM) \
	_(686, ZEND_ASSIGN_MUL_SPEC_CV_TMPVAR_OBJ) \
	_(687, ZEND_ASSIGN_MUL_SPEC_CV_TMPVAR) \
	_(688, ZEND_ASSIGN_MUL_SPEC_CV_TMPVAR_DIM) \
	_(689, ZEND_ASSIGN_MUL_SPEC_CV_TMPVAR_OBJ) \
	_(691, ZEND_ASSIGN_MUL_SPEC_CV_UNUSED_DIM) \
	_(693, ZEND_ASSIGN_MUL_SPEC_CV_CV) \
	_(694, ZEND_ASSIGN_MUL_SPEC_CV_CV_DIM) \
	_(695, ZEND_ASSIGN_MUL_SPEC_CV_CV_OBJ) \
	_(726, ZEND_ASSIGN_DIV_SPEC_VAR_CONST) \
	_(727, ZEND_ASSIGN_DIV_SPEC_VAR_CONST_DIM) \
	_(728, ZEND_ASSIGN_DIV_SPEC_VAR_CONST_OBJ) \
	_(729, ZEND_ASSIGN_DIV_SPEC_VAR_TMPVAR) \
	_(730, ZEND_ASSIGN_DIV_SPEC_VAR_TMPVAR_DIM) \
	_(731, ZEND_ASSIGN_DIV_SPEC_VAR_TMPVAR_OBJ) \
	_(732, ZEND_ASSIGN_DIV_SPEC_VAR_TMPVAR) \
	_(733, ZEND_ASSIGN_DIV_SPEC_VAR_TMPVAR_DIM) \
	_(734, ZEND_ASSIGN_DIV_SPEC_VAR_TMPVAR_OBJ) \
	_(736, ZEND_ASSIGN_DIV_SPEC_VAR_UNUSED_DIM) \
	_(738, ZEND_ASSIGN_DIV_SPEC_VAR_CV) \
	_(739, ZEND_ASSIGN_DIV_SPEC_VAR_CV_DIM) \
	_(740, ZEND_ASSIGN_DIV_SPEC_VAR_CV_OBJ) \
	_(743, ZEND_ASSIGN_DIV_SPEC_UNUSED_CONST_OBJ) \
	_(746, ZEND_ASSIGN_DIV_SPEC_UNUSED_TMPVAR_OBJ) \
	_(749, ZEND_ASSIGN_DIV_SPEC_UNUSED_TMPVAR_OBJ) \
	_(755, ZEND_ASSIGN_DIV_SPEC_UNUSED_CV_OBJ) \
	_(756, ZEND_ASSIGN_DIV_SPEC_CV_CONST) \
	_(757, ZEND_ASSIGN_DIV_SPEC_CV_CONST_DIM) \
	_(758, ZEND_ASSIGN_DIV_SPEC_CV_CONST_OBJ) \
	_(759, ZEND_ASSIGN_DIV_SPEC_CV_TMPVAR) \
	_(760, ZEND_ASSIGN_DIV_SPEC_CV_TMPVAR_DIM) \
	_(761, ZEND_ASSIGN_DIV_SPEC_CV_TMPVAR_OBJ) \
	_(762, ZEND_ASSIGN_DIV_SPEC_CV_TMPVAR) \
	_(763, ZEND_ASSIGN_DIV_SPEC_CV_TMPVAR_DIM) \
	_(764, ZEND_ASSIGN_DIV_SPEC_CV_TMPVAR_OBJ) \
	_(766, ZEND_ASSIGN_DIV_SPEC_CV_UNUSED_DIM) \
	_(768, ZEND_ASSIGN_DIV_SPEC_CV_CV) \
	_(769, ZEND_ASSIGN_DIV_SPEC_CV_CV_DIM) \
	_(770, ZEND_ASSIGN_DIV_SPEC_CV_CV_OBJ) \
	_(801, ZEND_ASSIGN_MOD_SPEC_VAR_CONST) \
	_(802, ZEND_ASSIGN_MOD_SPEC_VAR_CONST_DIM) \
	_(803, ZEND_ASSIGN_MOD_SPEC_VAR_CONST_OBJ) \
	_(804, ZEND_ASSIGN_MOD_SPEC_VAR_TMPVAR) \
	_(805, ZEND_ASSIGN_MOD_SPEC_VAR_TMPVAR_DIM) \
	_(806, ZEND_ASSIGN_MOD_SPEC_VAR_TMPVAR_OBJ) \
	_(807, ZEND_ASSIGN_MOD_SPEC_VAR_TMPVAR) \
	_(808, ZEND_ASSIGN_MOD_SPEC_VAR_TMPVAR_DIM) \
	_(809, ZEND_ASSIGN_MOD_SPEC_VAR_TMPVAR_OBJ) \
	_(811, ZEND_ASSIGN_MOD_SPEC_VAR_UNUSED_DIM) \
	_(813, ZEND_ASSIGN_MOD_SPEC_VAR_CV) \
	_(814, ZEND_ASSIGN_MOD_SPEC_VAR_CV_DIM) \
	_(815, ZEND_ASSIGN_MOD_SPEC_VAR_CV_OBJ) \
	_(818, ZEND_ASSIGN_MOD_SPEC_UNUSED_CONST_OBJ) \
	_(821, ZEND_ASSIGN_MOD_SPEC_UNUSED_TMPVAR_OBJ) \
	_(824, ZEND_ASSIGN_MOD_SPEC_UNUSED_TMPVAR_OBJ) \
	_(830, ZEND_ASSIGN_MOD_SPEC_UNUSED_CV_OBJ) \
	_(831, ZEND_ASSIGN_MOD_SPEC_CV_CONST) \
	_(832, ZEND_ASSIGN_MOD_SPEC_CV_CONST_DIM) \
	_(833, ZEND_ASSIGN_MOD_SPEC_CV_CONST_OBJ) \
	_(834, ZEND_ASSIGN_MOD_SPEC_CV_TMPVAR) \
	_(835, ZEND_ASSIGN_MOD_SPEC_CV_TMPVAR_DIM) \
	_(836, ZEND_ASSIGN_MOD_SPEC_CV_TMPVAR_OBJ) \
	_(837, ZEND_ASSIGN_MOD_SPEC_CV_TMPVAR) \
	_(838, ZEND_ASSIGN_MOD_SPEC_CV_TMPVAR_DIM) \
	_(839, ZEND_ASSIGN_MOD_SPEC_CV_TMPVAR_OBJ) \
	_(841, ZEND_ASSIGN_MOD_SPEC_CV_UNUSED_DIM) \
	_(843, ZEND_ASSIGN_MOD_SPEC_CV_CV) \
	_(844, ZEND_ASSIGN_MOD_SPEC_CV_CV_DIM) \
	_(845, ZEND_ASSIGN_MOD_SPEC_CV_CV_OBJ) \
	_(876, ZEND_ASSIGN_SL_SPEC_VAR_CONST) \
	_(877, ZEND_ASSIGN_SL_SPEC_VAR_CONST_DIM) \
	_(878, ZEND_ASSIGN_SL_SPEC_VAR_CONST_OBJ) \
	_(879, ZEND_ASSIGN_SL_SPEC_VAR_TMPVAR) \
	_(880, ZEND_ASSIGN_SL_SPEC_VAR_TMPVAR_DIM) \
	_(881, ZEND_ASSIGN_SL_SPEC_VAR_TMPVAR_OBJ) \
	_(882, ZEND_ASSIGN_SL_SPEC_VAR_TMPVAR) \
	_(883, ZEND_ASSIGN_SL_SPEC_VAR_TMPVAR_DIM) \
	_(884, ZEND_ASSIGN_SL_SPEC_VAR_TMPVAR_OBJ) \
	_(886, ZEND_ASSIGN_SL_SPEC_VAR_UNUSED_DIM) \
	_(888, ZEND_ASSIGN_SL_SPEC_VAR_CV) \
	_(889, ZEND_ASSIGN_SL_SPEC_VAR_CV_DIM) \
	_(890, ZEND_ASSIGN_SL_SPEC_VAR_CV_OBJ) \
	_(893, ZEND_ASSIGN_SL_SPEC_UNUSED_CONST_OBJ) \
	_(896, ZEND_ASSIGN_SL_SPEC_UNUSED_TMPVAR_OBJ) \
	_(899, ZEND_ASSIGN_SL_SPEC_UNUSED_TMPVAR_OBJ) \
	_(905, ZEND_ASSIGN_SL_SPEC_UNUSED_CV_OBJ) \
	_(906, ZEND_ASSIGN_SL_SPEC_CV_CONST) \
	_(907, ZEND_ASSIGN_SL_SPEC_CV_CONST_DIM) \
	_(908, ZEND_ASSIGN_SL_SPEC_CV_CONST_OBJ) \
	_(909, ZEND_ASSIGN_SL_SPEC_CV_TMPVAR) \
	_(910, ZEND_ASSIGN_SL_SPEC_CV_TMPVAR_DIM) \
	_(911, ZEND_ASSIGN_SL_SPEC_CV_TMPVAR_OBJ) \
	_(912, ZEND_ASSIGN_SL_SPEC_CV_TMPVAR) \
	_(913, ZEND_ASSIGN_SL_SPEC_CV_TMPVAR_DIM) \
	_(914, ZEND_ASSIGN_SL_SPEC_CV_TMPVAR_OBJ) \
	_(916, ZEND_ASSIGN_SL_SPEC_CV_UNUSED_DIM) \
	_(918, ZEND_ASSIGN_SL_SPEC_CV_CV) \
	_(919, ZEND_ASSIGN_SL_SPEC_CV_CV_DIM) \
	_(920, ZEND_ASSIGN_SL_SPEC_CV_CV_OBJ) \
	_(951, ZEND_ASSIGN_SR_SPEC_VAR_CONST) \
	_(952, ZEND_ASSIGN_SR_SPEC_VAR_CONST_DIM) \
	_(953, ZEND_ASSIGN_SR_SPEC_VAR_CONST_OBJ) \
	_(954, ZEND_ASSIGN_SR_SPEC_VAR_TMPVAR) \
	_(955, ZEND_ASSIGN_SR_SPEC_VAR_TMPVAR_DIM) \
	_(956, ZEND_ASSIGN_SR_SPEC_VAR_TMPVAR_OBJ) \
	_(957, ZEND_ASSIGN_SR_SPEC_VAR_TMPVAR) \
	_(958, ZEND_ASSIGN_SR_SPEC_VAR_TMPVAR_DIM) \
	_(959, ZEND_ASSIGN_SR_SPEC_VAR_TMPVAR_OBJ) \
	_(961, ZEND_ASSIGN_SR_SPEC_VAR_UNUSED_DIM) \
	_(963, ZEND_ASSIGN_SR_SPEC_VAR_CV) \
	_(964, ZEND_ASSIGN_SR_SPEC_VAR_CV_DIM) \
	_(965, ZEND_ASSIGN_SR_SPEC_VAR_CV_OBJ) \
	_(968, ZEND_ASSIGN_SR_SPEC_UNUSED_CONST_OBJ) \
	_(971, ZEND_ASSIGN_SR_SPEC_UNUSED_TMPVAR_OBJ) \
	_(974, ZEND_ASSIGN_SR_SPEC_UNUSED_TMPVAR_OBJ) \
	_(980, ZEND_ASSIGN_SR_SPEC_UNUSED_CV_OBJ) \
	_(981, ZEND_ASSIGN_SR_SPEC_CV_CONST) \
	_(982, ZEND_ASSIGN_SR_SPEC_CV_CONST_DIM) \
	_(983, ZEND_ASSIGN_SR_SPEC_CV_CONST_OBJ) \
	_(984, ZEND_ASSIGN_SR_SPEC_CV_TMPVAR) \
	_(985, ZEND_ASSIGN_SR_SPEC_CV_TMPVAR_DIM) \
	_(986, ZEND_ASSIGN_SR_SPEC_CV_TMPVAR_OBJ) \
	_(987, ZEND_ASSIGN_SR_SPEC_CV_TMPVAR) \
	_(988, ZEND_ASSIGN_SR_SPEC_CV_TMPVAR_DIM) \
	_(989, ZEND_ASSIGN_SR_SPEC_CV_TMPVAR_OBJ) \
	_(991, ZEND_ASSIGN_SR_SPEC_CV_UNUSED_DIM) \
	_(993, ZEND_ASSIGN_SR_SPEC_CV_CV) \
	_(994, ZEND_ASSIGN_SR_SPEC_CV_CV_DIM) \
	_(995, ZEND_ASSIGN_SR_SPEC_CV_CV_OBJ) \
	_(1026, ZEND_ASSIGN_CONCAT_SPEC_VAR_CONST) \
	_(1027, ZEND_ASSIGN_CONCAT_SPEC_VAR_CONST_DIM) \
	_(1028, ZEND_ASSIGN_CONCAT_SPEC_VAR_CONST_OBJ) \
	_(1029, ZEND_ASSIGN_CONCAT_SPEC_VAR_TMPVAR) \
	_(1030, ZEND_ASSIGN_CONCAT_SPEC_VAR_TMPVAR_DIM) \
	_(1031, ZEND_ASSIGN_CONCAT_SPEC_VAR_TMPVAR_OBJ) \
	_(1032, ZEND_ASSIGN_CONCAT_SPEC_VAR_TMPVAR) \
	_(1033, ZEND_ASSIGN_CONCAT_SPEC_VAR_TMPVAR_DIM) \
	_(1034, ZEND_ASSIGN_CONCAT_SPEC_VAR_TMPVAR_OBJ) \
	_(1036, ZEND_ASSIGN_CONCAT_SPEC_VAR_UNUSED_DIM) \
	_(1038, ZEND_ASSIGN_CONCAT_SPEC_VAR_CV) \
	_(1039, ZEND_ASSIGN_CONCAT_SPEC_VAR_CV_DIM) \
	_(1040, ZEND_ASSIGN_CONCAT_SPEC_VAR_CV_OBJ) \
	_(1043, ZEND_ASSIGN_CONCAT_SPEC_UNUSED_CONST_OBJ) \
	_(1046, ZEND_ASSIGN_CONCAT_SPEC_UNUSED_TMPVAR_OBJ) \
	_(1049, ZEND_ASSIGN_CONCAT_SPEC_UNUSED_TMPVAR_OBJ) \
	_(1055, ZEND_ASSIGN_CONCAT_SPEC_UNUSED_CV_OBJ) \
	_(1056, ZEND_ASSIGN_CONCAT_SPEC_CV_CONST) \
	_(1057, ZEND_ASSIGN_CONCAT_SPEC_CV_CONST_DIM) \
	_(1058, ZEND_ASSIGN_CONCAT_SPEC_CV_CONST_OBJ) \
	_(1059, ZEND_ASSIGN_CONCAT_SPEC_CV_TMPVAR) \
	_(1060, ZEND_ASSIGN_CONCAT_SPEC_CV_TMPVAR_DIM) \
	_(1061, ZEND_ASSIGN_CONCAT_SPEC_CV_TMPVAR_OBJ) \
	_(1062, ZEND_ASSIGN_CONCAT_SPEC_CV_TMPVAR) \
	_(1063, ZEND_ASSIGN_CONCAT_SPEC_CV_TMPVAR_DIM) \
	_(1064, ZEND_ASSIGN_CONCAT_SPEC_CV_TMPVAR_OBJ) \
	_(1066, ZEND_ASSIGN_CONCAT_SPEC_CV_UNUSED_DIM) \
	_(1068, ZEND_ASSIGN_CONCAT_SPEC_CV_CV) \
	_(1069, ZEND_ASSIGN_CONCAT_SPEC_CV_CV_DIM) \
	_(1070, ZEND_ASSIGN_CONCAT_SPEC_CV_CV_OBJ) \
	_(1101, ZEND_ASSIGN_BW_OR_SPEC_VAR_CONST) \
	_(1102, ZEND_ASSIGN_BW_OR_SPEC_VAR_CONST_DIM) \
	_(1103, ZEND_ASSIGN_BW_OR_SPEC_VAR_CONST_OBJ) \
	_(1104, ZEND_ASSIGN_BW_OR_SPEC_VAR_TMPVAR) \
	_(1105, ZEND_ASSIGN_BW_OR_SPEC_VAR_TMPVAR_DIM) \
	_(1106, ZEND_ASSIGN_BW_OR_SPEC_VAR_TMPVAR_OBJ) \
	_(1107, ZEND_ASSIGN_BW_OR_SPEC_VAR_TMPVAR) \
	_(1108, ZEND_ASSIGN_BW_OR_SPEC_VAR_TMPVAR_DIM) \
	_(1109, ZEND_ASSIGN_BW_OR_SPEC_VAR_TMPVAR_OBJ) \
	_(1111, ZEND_ASSIGN_BW_OR_SPEC_VAR_UNUSED_DIM) \
	_(1113, ZEND_ASSIGN_BW_OR_SPEC_VAR_CV) \
	_(1114, ZEND_ASSIGN_BW_OR_SPEC_VAR_CV_DIM) \
	_(1115, ZEND_ASSIGN_BW_OR_SPEC_VAR_CV_OBJ) \
	_(1118, ZEND_ASSIGN_BW_OR_SPEC_UNUSED_CONST_OBJ) \
	_(1121, ZEND_ASSIGN_BW_OR_SPEC_UNUSED_TMPVAR_OBJ) \
	_(1124, ZEND_ASSIGN_BW_OR_SPEC_UNUSED_TMPVAR_OBJ) \
	_(1130, ZEND_ASSIGN_BW_OR_SPEC_UNUSED_CV_OBJ) \
	_(1131, ZEND_ASSIGN_BW_OR_SPEC_CV_CONST) \
	_(1132, ZEND_ASSIGN_BW_OR_SPEC_CV_CONST_DIM) \
	_(1133, ZEND_ASSIGN_BW_OR_SPEC_CV_CONST_OBJ) \
	_(1134, ZEND_ASSIGN_BW_OR_SPEC_CV_TMPVAR) \
	_(1135, ZEND_ASSIGN_BW_OR_SPEC_CV_TMPVAR_DIM) \
	_(1136, ZEND_ASSIGN_BW_OR_SPEC_CV_TMPVAR_OBJ) \
	_(1137, ZEND_ASSIGN_BW_OR_SPEC_CV_TMPVAR) \
	_(1138, ZEND_ASSIGN_BW_OR_SPEC_CV_TMPVAR_DIM) \
	_(1139, ZEND_ASSIGN_BW_OR_SPEC_CV_TMPVAR_OBJ) \
	_(1141, ZEND_ASSIGN_BW_OR_SPEC_CV_UNUSED_DIM) \
	_(1143, ZEND_ASSIGN_BW_OR_SPEC_CV_CV) \
	_(1144, ZEND_ASSIGN_BW_OR_SPEC_CV_CV_DIM) \
	_(1145, ZEND_ASSIGN_BW_OR_SPEC_CV_CV_OBJ) \
	_(1176, ZEND_ASSIGN_BW_AND_SPEC_VAR_CONST) \
	_(1177, ZEND_ASSIGN_BW_AND_SPEC_VAR_CONST_DIM) \
	_(1178, ZEND_ASSIGN_BW_AND_SPEC_VAR_CONST_OBJ) \
	_(1179, ZEND_ASSIGN_BW_AND_SPEC_VAR_TMPVAR) \
	_(1180, ZEND_ASSIGN_BW_AND_SPEC_VAR_TMPVAR_DIM) \
	_(1181, ZEND_ASSIGN_BW_AND_SPEC_VAR_TMPVAR_OBJ) \
	_(1182, ZEND_ASSIGN_BW_AND_SPEC_VAR_TMPVAR) \
	_(1183, ZEND_ASSIGN_BW_AND_SPEC_VAR_TMPVAR_DIM) \
	_(1184, ZEND_ASSIGN_BW_AND_SPEC_VAR_TMPVAR_OBJ) \
	_(1186, ZEND_ASSIGN_BW_AND_SPEC_VAR_UNUSED_DIM) \
	_(1188, ZEND_ASSIGN_BW_AND_SPEC_VAR_CV) \
	_(1189, ZEND_ASSIGN_BW_AND_SPEC_VAR_CV_DIM) \
	_(1190, ZEND_ASSIGN_BW_AND_SPEC_VAR_CV_OBJ) \
	_(1193, ZEND_ASSIGN_BW_AND_SPEC_UNUSED_CONST_OBJ) \
	_(1196, ZEND_ASSIGN_BW_AND_SPEC_UNUSED_TMPVAR_OBJ) \
	_(1199, ZEND_ASSIGN_BW_AND_SPEC_UNUSED_TMPVAR_OBJ) \
	_(1205, ZEND_ASSIGN_BW_AND_SPEC_UNUSED_CV_OBJ) \
	_(1206, ZEND_ASSIGN_BW_AND_SPEC_CV_CONST) \
	_(1207, ZEND_ASSIGN_BW_AND_SPEC_CV_CONST_DIM) \
	_(1208, ZEND_ASSIGN_BW_AND_SPEC_CV_CONST_OBJ) \
	_(1209, ZEND_ASSIGN_BW_AND_SPEC_CV_TMPVAR) \
	_(1210, ZEND_ASSIGN_BW_AND_SPEC_CV_TMPVAR_DIM) \
	_(1211, ZEND_ASSIGN_BW_AND_SPEC_CV_TMPVAR_OBJ) \
	_(1212, ZEND_ASSIGN_BW_AND_SPEC_CV_TMPVAR) \
	_(1213, ZEND_ASSIGN_BW_AND_SPEC_CV_TMPVAR_DIM) \
	_(1214, ZEND_ASSIGN_BW_AND_SPEC_CV_TMPVAR_OBJ) \
	_(1216, ZEND_ASSIGN_BW_AND_SPEC_CV_UNUSED_DIM) \
	_(1218, ZEND_ASSIGN_BW_AND_SPEC_CV_CV) \
	_(1219, ZEND_ASSIGN_BW_AND_SPEC_CV_CV_DIM) \
	_(1220, ZEND_ASSIGN_BW_AND_SPEC_CV_CV_OBJ) \
	_(1251, ZEND_ASSIGN_BW_XOR_SPEC_VAR_CONST) \
	_(1252, ZEND_ASSIGN_BW_XOR_SPEC_VAR_CONST_DIM) \
	_(1253, ZEND_ASSIGN_BW_XOR_SPEC_VAR_CONST_OBJ) \
	_(1254, ZEND_ASSIGN_BW_XOR_SPEC_VAR_TMPVAR) \
	_(1255, ZEND_ASSIGN_BW_XOR_SPEC_VAR_TMPVAR_DIM) \
	_(1256, ZEND_ASSIGN_BW_XOR_SPEC_VAR_TMPVAR_OBJ) \
	_(1257, ZEND_ASSIGN_BW_XOR_SPEC_VAR_TMPVAR) \
	_(1258, ZEND_ASSIGN_BW_XOR_SPEC_VAR_TMPVAR_DIM) \
	_(1259, ZEND_ASSIGN_BW_XOR_SPEC_VAR_TMPVAR_OBJ) \
	_(1261, ZEND_ASSIGN_BW_XOR_SPEC_VAR_UNUSED_DIM) \
	_(1263, ZEND_ASSIGN_BW_XOR_SPEC_VAR_CV) \
	_(1264, ZEND_ASSIGN_BW_XOR_SPEC_VAR_CV_DIM) \
	_(1265, ZEND_ASSIGN_BW_XOR_SPEC_VAR_CV_OBJ) \
	_(1268, ZEND_ASSIGN_BW_XOR_SPEC_UNUSED_CONST_OBJ) \
	_(1271, ZEND_ASSIGN_BW_XOR_SPEC_UNUSED_TMPVAR_OBJ) \
	_(1274, ZEND_ASSIGN_BW_XOR_SPEC_UNUSED_TMPVAR_OBJ) \
	_(1280, ZEND_ASSIGN_BW_XOR_SPEC_UNUSED_CV_OBJ) \
	_(1281, ZEND_ASSIGN_BW_XOR_SPEC_CV_CONST) \
	_(1282, ZEND_ASSIGN_BW_XOR_SPEC_CV_CONST_DIM) \
	_(1283, ZEND_ASSIGN_BW_XOR_SPEC_CV_CONST_OBJ) \
	_(1284, ZEND_ASSIGN_BW_XOR_SPEC_CV_TMPVAR) \
	_(1285, ZEND_ASSIGN_BW_XOR_SPEC_CV_TMPVAR_DIM) \
	_(1286, ZEND_ASSIGN_BW_XOR_SPEC_CV_TMPVAR_OBJ) \
	_(1287, ZEND_ASSIGN_BW_XOR_SPEC_CV_TMPVAR) \
	_(1288, ZEND_ASSIGN_BW_XOR_SPEC_CV_TMPVAR_DIM) \
	_(1289, ZEND_ASSIGN_BW_XOR_SPEC_CV_TMPVAR_OBJ) \
	_(1291, ZEND_ASSIGN_BW_XOR_SPEC_CV_UNUSED_DIM) \
	_(1293, ZEND_ASSIGN_BW_XOR_SPEC_CV_CV) \
	_(1294, ZEND_ASSIGN_BW_XOR_SPEC_CV_CV_DIM) \
	_(1295, ZEND_ASSIGN_BW_XOR_SPEC_CV_CV_OBJ) \
	_(1300, ZEND_PRE_INC_SPEC_VAR_RETVAL_UNUSED) \
	_(1301, ZEND_PRE_INC_SPEC_VAR_RETVAL_USED) \
	_(1304, ZEND_PRE_INC_SPEC_CV_RETVAL_UNUSED) \
	_(1305, ZEND_PRE_INC_SPEC_CV_RETVAL_USED) \
	_(1310, ZEND_PRE_DEC_SPEC_VAR_RETVAL_UNUSED) \
	_(1311, ZEND_PRE_DEC_SPEC_VAR_RETVAL_USED) \
	_(1314, ZEND_PRE_DEC_SPEC_CV_RETVAL_UNUSED) \
	_(1315, ZEND_PRE_DEC_SPEC_CV_RETVAL_USED) \
	_(1318, ZEND_POST_INC_SPEC_VAR) \
	_(1320, ZEND_POST_INC_SPEC_CV) \
	_(1323, ZEND_POST_DEC_SPEC_VAR) \
	_(1325, ZEND_POST_DEC_SPEC_CV) \
	_(1346, ZEND_ASSIGN_SPEC_VAR_CONST_RETVAL_UNUSED) \
	_(1347, ZEND_ASSIGN_SPEC_VAR_CONST_RETVAL_USED) \
	_(1348, ZEND_ASSIGN_SPEC_VAR_TMP_RETVAL_UNUSED) \
	_(1349, ZEND_ASSIGN_SPEC_VAR_TMP_RETVAL_USED) \
	_(1350, ZEND_ASSIGN_SPEC_VAR_VAR_RETVAL_UNUSED) \
	_(1351, ZEND_ASSIGN_SPEC_VAR_VAR_RETVAL_USED) \
	_(1354, ZEND_ASSIGN_SPEC_VAR_CV_RETVAL_UNUSED) \
	_(1355, ZEND_ASSIGN_SPEC_VAR_CV_RETVAL_USED) \
	_(1366, ZEND_ASSIGN_SPEC_CV_CONST_RETVAL_UNUSED) \
	_(1367, ZEND_ASSIGN_SPEC_CV_CONST_RETVAL_USED) \
	_(1368, ZEND_ASSIGN_SPEC_CV_TMP_RETVAL_UNUSED) \
	_(1369, ZEND_ASSIGN_SPEC_CV_TMP_RETVAL_USED) \
	_(1370, ZEND_ASSIGN_SPEC_CV_VAR_RETVAL_UNUSED) \
	_(1371, ZEND_ASSIGN_SPEC_CV_VAR_RETVAL_USED) \
	_(1374, ZEND_ASSIGN_SPEC_CV_CV_RETVAL_UNUSED) \
	_(1375, ZEND_ASSIGN_SPEC_CV_CV_RETVAL_USED) \
	_(1388, ZEND_ASSIGN_REF_SPEC_VAR_VAR) \
	_(1390, ZEND_ASSIGN_REF_SPEC_VAR_CV) \
	_(1398, ZEND_ASSIGN_REF_SPEC_CV_VAR) \
	_(1400, ZEND_ASSIGN_REF_SPEC_CV_CV) \
	_(1401, ZEND_ECHO_SPEC_CONST) \
	_(1402, ZEND_ECHO_SPEC_TMPVAR) \
	_(1403, ZEND_ECHO_SPEC_TMPVAR) \
	_(1405, ZEND_ECHO_SPEC_CV) \
	_(1406, ZEND_GENERATOR_CREATE_SPEC) \
	_(1407, ZEND_JMP_SPEC) \
	_(1408, ZEND_JMPZ_SPEC_CONST) \
	_(1409, ZEND_JMPZ_SPEC_TMPVAR) \
	_(1410, ZEND_JMPZ_SPEC_TMPVAR) \
	_(1412, ZEND_JMPZ_SPEC_CV) \
	_(1413, ZEND_JMPNZ_SPEC_CONST) \
	_(1414, ZEND_JMPNZ_SPEC_TMPVAR) \
	_(1415, ZEND_JMPNZ_SPEC_TMPVAR) \
	_(1417, ZEND_JMPNZ_SPEC_CV) \
	_(1418, ZEND_JMPZNZ_SPEC_CONST) \
	_(1419, ZEND_JMPZNZ_SPEC_TMPVAR) \
	_(1420, ZEND_JMPZNZ_SPEC_TMPVAR) \
	_(1422, ZEND_JMPZNZ_SPEC_CV) \
	_(1423, ZEND_JMPZ_EX_SPEC_CONST) \
	_(1424, ZEND_JMPZ_EX_SPEC_TMPVAR) \
	_(1425, ZEND_JMPZ_EX_SPEC_TMPVAR) \
	_(1427, ZEND_JMPZ_EX_SPEC_CV) \
	_(1428, ZEND_JMPNZ_EX_SPEC_CONST) \
	_(1429, ZEND_JMPNZ_EX_SPEC_TMPVAR) \
	_(1430, ZEND_JMPNZ_EX_SPEC_TMPVAR) \
	_(1432, ZEND_JMPNZ_EX_SPEC_CV) \
	_(1433, ZEND_CASE_SPEC_TMPVAR_CONST) \
	_(1434, ZEND_CASE_SPEC_TMPVAR_TMPVAR) \
	_(1435, ZEND_CASE_SPEC_TMPVAR_TMPVAR) \
	_(1437, ZEND_CASE_SPEC_TMPVAR_CV) \
	_(1438, ZEND_CHECK_VAR_SPEC_CV_UNUSED) \
	_(1439, ZEND_SEND_VAR_NO_REF_EX_SPEC_VAR) \
	_(1440, ZEND_SEND_VAR_NO_REF_EX_SPEC_VAR_QUICK) \
	_(1443, ZEND_MAKE_REF_SPEC_VAR_UNUSED) \
	_(1445, ZEND_MAKE_REF_SPEC_CV_UNUSED) \
	_(1446, ZEND_BOOL_SPEC_CONST) \
	_(1447, ZEND_BOOL_SPEC_TMPVAR) \
	_(1448, ZEND_BOOL_SPEC_TMPVAR) \
	_(1450, ZEND_BOOL_SPEC_CV) \
	_(1451, ZEND_FAST_CONCAT_SPEC_CONST_CONST) \
	_(1452, ZEND_FAST_CONCAT_SPEC_CONST_TMPVAR) \
	_(1453, ZEND_FAST_CONCAT_SPEC_CONST_TMPVAR) \
	_(1455, ZEND_FAST_CONCAT_SPEC_CONST_CV) \
	_(1456, ZEND_FAST_CONCAT_SPEC_TMPVAR_CONST) \
	_(1457, ZEND_FAST_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(1458, ZEND_FAST_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(1460, ZEND_FAST_CONCAT_SPEC_TMPVAR_CV) \
	_(1461, ZEND_FAST_CONCAT_SPEC_TMPVAR_CONST) \
	_(1462, ZEND_FAST_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(1463, ZEND_FAST_CONCAT_SPEC_TMPVAR_TMPVAR) \
	_(1465, ZEND_FAST_CONCAT_SPEC_TMPVAR_CV) \
	_(1471, ZEND_FAST_CONCAT_SPEC_CV_CONST) \
	_(1472, ZEND_FAST_CONCAT_SPEC_CV_TMPVAR) \
	_(1473, ZEND_FAST_CONCAT_SPEC_CV_TMPVAR) \
	_(1475, ZEND_FAST_CONCAT_SPEC_CV_CV) \
	_(1476, ZEND_ROPE_INIT_SPEC_UNUSED_CONST) \
	_(1477, ZEND_ROPE_INIT_SPEC_UNUSED_TMPVAR) \
	_(1478, ZEND_ROPE_INIT_SPEC_UNUSED_TMPVAR) \
	_(1480, ZEND_ROPE_INIT_SPEC_UNUSED_CV) \
	_(1481, ZEND_ROPE_ADD_SPEC_TMP_CONST) \
	_(1482, ZEND_ROPE_ADD_SPEC_TMP_TMPVAR) \
	_(1483, ZEND_ROPE_ADD_SPEC_TMP_TMPVAR) \
	_(1485, ZEND_ROPE_ADD_SPEC_TMP_CV) \
	_(1486, ZEND_ROPE_END_SPEC_TMP_CONST) \
	_(1487, ZEND_ROPE_END_SPEC_TMP_TMPVAR) \
	_(1488, ZEND_ROPE_END_SPEC_TMP_TMPVAR) \
	_(1490, ZEND_ROPE_END_SPEC_TMP_CV) \
	_(1491, ZEND_BEGIN_SILENCE_SPEC) \
	_(1492, ZEND_END_SILENCE_SPEC_TMP) \
	_(1493, ZEND_INIT_FCALL_BY_NAME_SPEC_CONST) \
	_(1494, ZEND_DO_FCALL_SPEC_RETVAL_UNUSED) \
	_(1495, ZEND_DO_FCALL_SPEC_RETVAL_USED) \
	_(1496, ZEND_INIT_FCALL_SPEC_CONST) \
	_(1497, ZEND_RETURN_SPEC_CONST) \
	_(1498, ZEND_RETURN_SPEC_TMP) \
	_(1499, ZEND_RETURN_SPEC_VAR) \
	_(1501, ZEND_RETURN_SPEC_CV) \
	_(1502, ZEND_RECV_SPEC_UNUSED) \
	_(1503, ZEND_RECV_INIT_SPEC_CONST) \
	_(1504, ZEND_SEND_VAL_SPEC_CONST) \
	_(1505, ZEND_SEND_VAL_SPEC_TMPVAR) \
	_(1506, ZEND_SEND_VAL_SPEC_TMPVAR) \
	_(1513, ZEND_SEND_VAR_EX_SPEC_VAR) \
	_(1514, ZEND_SEND_VAR_EX_SPEC_VAR_QUICK) \
	_(1517, ZEND_SEND_VAR_EX_SPEC_CV) \
	_(1518, ZEND_SEND_VAR_EX_SPEC_CV_QUICK) \
	_(1521, ZEND_SEND_REF_SPEC_VAR) \
	_(1523, ZEND_SEND_REF_SPEC_CV) \
	_(1524, ZEND_NEW_SPEC_CONST_UNUSED) \
	_(1526, ZEND_NEW_SPEC_VAR_UNUSED) \
	_(1527, ZEND_NEW_SPEC_UNUSED_UNUSED) \
	_(1529, ZEND_INIT_NS_FCALL_BY_NAME_SPEC_CONST) \
	_(1530, ZEND_FREE_SPEC_TMPVAR) \
	_(1531, ZEND_INIT_ARRAY_SPEC_CONST_CONST) \
	_(1532, ZEND_INIT_ARRAY_SPEC_CONST_TMPVAR) \
	_(1533, ZEND_INIT_ARRAY_SPEC_CONST_TMPVAR) \
	_(1534, ZEND_INIT_ARRAY_SPEC_CONST_UNUSED) \
	_(1535, ZEND_INIT_ARRAY_SPEC_CONST_CV) \
	_(1536, ZEND_INIT_ARRAY_SPEC_TMP_CONST) \
	_(1537, ZEND_INIT_ARRAY_SPEC_TMP_TMPVAR) \
	_(1538, ZEND_INIT_ARRAY_SPEC_TMP_TMPVAR) \
	_(1539, ZEND_INIT_ARRAY_SPEC_TMP_UNUSED) \
	_(1540, ZEND_INIT_ARRAY_SPEC_TMP_CV) \
	_(1541, ZEND_INIT_ARRAY_SPEC_VAR_CONST) \
	_(1542, ZEND_INIT_ARRAY_SPEC_VAR_TMPVAR) \
	_(1543, ZEND_INIT_ARRAY_SPEC_VAR_TMPVAR) \
	_(1544, ZEND_INIT_ARRAY_SPEC_VAR_UNUSED) \
	_(1545, ZEND_INIT_ARRAY_SPEC_VAR_CV) \
	_(1551, ZEND_INIT_ARRAY_SPEC_CV_CONST) \
	_(1552, ZEND_INIT_ARRAY_SPEC_CV_TMPVAR) \
	_(1553, ZEND_INIT_ARRAY_SPEC_CV_TMPVAR) \
	_(1554, ZEND_INIT_ARRAY_SPEC_CV_UNUSED) \
	_(1555, ZEND_INIT_ARRAY_SPEC_CV_CV) \
	_(1556, ZEND_ADD_ARRAY_ELEMENT_SPEC_CONST_CONST) \
	_(1557, ZEND_ADD_ARRAY_ELEMENT_SPEC_CONST_TMPVAR) \
	_(1558, ZEND_ADD_ARRAY_ELEMENT_SPEC_CONST_TMPVAR) \
	_(1559, ZEND_ADD_ARRAY_ELEMENT_SPEC_CONST_UNUSED) \
	_(1560, ZEND_ADD_ARRAY_ELEMENT_SPEC_CONST_CV) \
	_(1561, ZEND_ADD_ARRAY_ELEMENT_SPEC_TMP_CONST) \
	_(1562, ZEND_ADD_ARRAY_ELEMENT_SPEC_TMP_TMPVAR) \
	_(1563, ZEND_ADD_ARRAY_ELEMENT_SPEC_TMP_TMPVAR) \
	_(1564, ZEND_ADD_ARRAY_ELEMENT_SPEC_TMP_UNUSED) \
	_(1565, ZEND_ADD_ARRAY_ELEMENT_SPEC_TMP_CV) \
	_(1566, ZEND_ADD_ARRAY_ELEMENT_SPEC_VAR_CONST) \
	_(1567, ZEND_ADD_ARRAY_ELEMENT_SPEC_VAR_TMPVAR) \
	_(1568, ZEND_ADD_ARRAY_ELEMENT_SPEC_VAR_TMPVAR) \
	_(1569, ZEND_ADD_ARRAY_ELEMENT_SPEC_VAR_UNUSED) \
	_(1570, ZEND_ADD_ARRAY_ELEMENT_SPEC_VAR_CV) \
	_(1576, ZEND_ADD_ARRAY_ELEMENT_SPEC_CV_CONST) \
	_(1577, ZEND_ADD_ARRAY_ELEMENT_SPEC_CV_TMPVAR) \
	_(1578, ZEND_ADD_ARRAY_ELEMENT_SPEC_CV_TMPVAR) \
	_(1579, ZEND_ADD_ARRAY_ELEMENT_SPEC_CV_UNUSED) \
	_(1580, ZEND_ADD_ARRAY_ELEMENT_SPEC_CV_CV) \
	_(1581, ZEND_INCLUDE_OR_EVAL_SPEC_CONST) \
	_(1582, ZEND_INCLUDE_OR_EVAL_SPEC_TMPVAR) \
	_(1583, ZEND_INCLUDE_OR_EVAL_SPEC_TMPVAR) \
	_(1585, ZEND_INCLUDE_OR_EVAL_SPEC_CV) \
	_(1586, ZEND_UNSET_VAR_SPEC_CONST_UNUSED) \
	_(1587, ZEND_UNSET_VAR_SPEC_TMPVAR_UNUSED) \
	_(1588, ZEND_UNSET_VAR_SPEC_TMPVAR_UNUSED) \
	_(1590, ZEND_UNSET_VAR_SPEC_CV_UNUSED) \
	_(1601, ZEND_UNSET_DIM_SPEC_VAR_CONST) \
	_(1602, ZEND_UNSET_DIM_SPEC_VAR_TMPVAR) \
	_(1603, ZEND_UNSET_DIM_SPEC_VAR_TMPVAR) \
	_(1605, ZEND_UNSET_DIM_SPEC_VAR_CV) \
	_(1611, ZEND_UNSET_DIM_SPEC_CV_CONST) \
	_(1612, ZEND_UNSET_DIM_SPEC_CV_TMPVAR) \
	_(1613, ZEND_UNSET_DIM_SPEC_CV_TMPVAR) \
	_(1615, ZEND_UNSET_DIM_SPEC_CV_CV) \
	_(1626, ZEND_UNSET_OBJ_SPEC_VAR_CONST) \
	_(1627, ZEND_UNSET_OBJ_SPEC_VAR_TMPVAR) \
	_(1628, ZEND_UNSET_OBJ_SPEC_VAR_TMPVAR) \
	_(1630, ZEND_UNSET_OBJ_SPEC_VAR_CV) \
	_(1631, ZEND_UNSET_OBJ_SPEC_UNUSED_CONST) \
	_(1632, ZEND_UNSET_OBJ_SPEC_UNUSED_TMPVAR) \
	_(1633, ZEND_UNSET_OBJ_SPEC_UNUSED_TMPVAR) \
	_(1635, ZEND_UNSET_OBJ_SPEC_UNUSED_CV) \
	_(1636, ZEND_UNSET_OBJ_SPEC_CV_CONST) \
	_(1637, ZEND_UNSET_OBJ_SPEC_CV_TMPVAR) \
	_(1638, ZEND_UNSET_OBJ_SPEC_CV_TMPVAR) \
	_(1640, ZEND_UNSET_OBJ_SPEC_CV_CV) \
	_(1641, ZEND_FE_RESET_R_SPEC_CONST) \
	_(1642, ZEND_FE_RESET_R_SPEC_TMP) \
	_(1643, ZEND_FE_RESET_R_SPEC_VAR) \
	_(1645, ZEND_FE_RESET_R_SPEC_CV) \
	_(1646, ZEND_FE_FETCH_R_SPEC_VAR) \
	_(1647, ZEND_EXIT_SPEC_CONST) \
	_(1648, ZEND_EXIT_SPEC_TMPVAR) \
	_(1649, ZEND_EXIT_SPEC_TMPVAR) \
	_(1650, ZEND_EXIT_SPEC_UNUSED) \
	_(1651, ZEND_EXIT_SPEC_CV) \
	_(1652, ZEND_FETCH_R_SPEC_CONST_UNUSED) \
	_(1653, ZEND_FETCH_R_SPEC_TMPVAR_UNUSED) \
	_(1654, ZEND_FETCH_R_SPEC_TMPVAR_UNUSED) \
	_(1656, ZEND_FETCH_R_SPEC_CV_UNUSED) \
	_(1657, ZEND_FETCH_DIM_R_SPEC_CONST_CONST) \
	_(1658, ZEND_FETCH_DIM_R_SPEC_CONST_TMPVAR) \
	_(1659, ZEND_FETCH_DIM_R_SPEC_CONST_TMPVAR) \
	_(1661, ZEND_FETCH_DIM_R_SPEC_CONST_CV) \
	_(1662, ZEND_FETCH_DIM_R_SPEC_TMPVAR_CONST) \
	_(1663, ZEND_FETCH_DIM_R_SPEC_TMPVAR_TMPVAR) \
	_(1664, ZEND_FETCH_DIM_R_SPEC_TMPVAR_TMPVAR) \
	_(1666, ZEND_FETCH_DIM_R_SPEC_TMPVAR_CV) \
	_(1667, ZEND_FETCH_DIM_R_SPEC_TMPVAR_CONST) \
	_(1668, ZEND_FETCH_DIM_R_SPEC_TMPVAR_TMPVAR) \
	_(1669, ZEND_FETCH_DIM_R_SPEC_TMPVAR_TMPVAR) \
	_(1671, ZEND_FETCH_DIM_R_SPEC_TMPVAR_CV) \
	_(1677, ZEND_FETCH_DIM_R_SPEC_CV_CONST) \
	_(1678, ZEND_FETCH_DIM_R_SPEC_CV_TMPVAR) \
	_(1679, ZEND_FETCH_DIM_R_SPEC_CV_TMPVAR) \
	_(1681, ZEND_FETCH_DIM_R_SPEC_CV_CV) \
	_(1682, ZEND_FETCH_OBJ_R_SPEC_CONST_CONST) \
	_(1683, ZEND_FETCH_OBJ_R_SPEC_CONST_TMPVAR) \
	_(1684, ZEND_FETCH_OBJ_R_SPEC_CONST_TMPVAR) \
	_(1686, ZEND_FETCH_OBJ_R_SPEC_CONST_CV) \
	_(1687, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_CONST) \
	_(1688, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_TMPVAR) \
	_(1689, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_TMPVAR) \
	_(1691, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_CV) \
	_(1692, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_CONST) \
	_(1693, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_TMPVAR) \
	_(1694, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_TMPVAR) \
	_(1696, ZEND_FETCH_OBJ_R_SPEC_TMPVAR_CV) \
	_(1697, ZEND_FETCH_OBJ_R_SPEC_UNUSED_CONST) \
	_(1698, ZEND_FETCH_OBJ_R_SPEC_UNUSED_TMPVAR) \
	_(1699, ZEND_FETCH_OBJ_R_SPEC_UNUSED_TMPVAR) \
	_(1701, ZEND_FETCH_OBJ_R_SPEC_UNUSED_CV) \
	_(1702, ZEND_FETCH_OBJ_R_SPEC_CV_CONST) \
	_(1703, ZEND_FETCH_OBJ_R_SPEC_CV_TMPVAR) \
	_(1704, ZEND_FETCH_OBJ_R_SPEC_CV_TMPVAR) \
	_(1706, ZEND_FETCH_OBJ_R_SPEC_CV_CV) \
	_(1707, ZEND_FETCH_W_SPEC_CONST_UNUSED) \
	_(1708, ZEND_FETCH_W_SPEC_TMPVAR_UNUSED) \
	_(1709, ZEND_FETCH_W_SPEC_TMPVAR_UNUSED) \
	_(1711, ZEND_FETCH_W_SPEC_CV_UNUSED) \
	_(1722, ZEND_FETCH_DIM_W_SPEC_VAR_CONST) \
	_(1723, ZEND_FETCH_DIM_W_SPEC_VAR_TMPVAR) \
	_(1724, ZEND_FETCH_DIM_W_SPEC_VAR_TMPVAR) \
	_(1725, ZEND_FETCH_DIM_W_SPEC_VAR_UNUSED) \
	_(1726, ZEND_FETCH_DIM_W_SPEC_VAR_CV) \
	_(1732, ZEND_FETCH_DIM_W_SPEC_CV_CONST) \
	_(1733, ZEND_FETCH_DIM_W_SPEC_CV_TMPVAR) \
	_(1734, ZEND_FETCH_DIM_W_SPEC_CV_TMPVAR) \
	_(1735, ZEND_FETCH_DIM_W_SPEC_CV_UNUSED) \
	_(1736, ZEND_FETCH_DIM_W_SPEC_CV_CV) \
	_(1747, ZEND_FETCH_OBJ_W_SPEC_VAR_CONST) \
	_(1748, ZEND_FETCH_OBJ_W_SPEC_VAR_TMPVAR) \
	_(1749, ZEND_FETCH_OBJ_W_SPEC_VAR_TMPVAR) \
	_(1751, ZEND_FETCH_OBJ_W_SPEC_VAR_CV) \
	_(1752, ZEND_FETCH_OBJ_W_SPEC_UNUSED_CONST) \
	_(1753, ZEND_FETCH_OBJ_W_SPEC_UNUSED_TMPVAR) \
	_(1754, ZEND_FETCH_OBJ_W_SPEC_UNUSED_TMPVAR) \
	_(1756, ZEND_FETCH_OBJ_W_SPEC_UNUSED_CV) \
	_(1757, ZEND_FETCH_OBJ_W_SPEC_CV_CONST) \
	_(1758, ZEND_FETCH_OBJ_W_SPEC_CV_TMPVAR) \
	_(1759, ZEND_FETCH_OBJ_W_SPEC_CV_TMPVAR) \
	_(1761, ZEND_FETCH_OBJ_W_SPEC_CV_CV) \
	_(1762, ZEND_FETCH_RW_SPEC_CONST_UNUSED) \
	_(1763, ZEND_FETCH_RW_SPEC_TMPVAR_UNUSED) \
	_(1764, ZEND_FETCH_RW_SPEC_TMPVAR_UNUSED) \
	_(1766, ZEND_FETCH_RW_SPEC_CV_UNUSED) \
	_(1777, ZEND_FETCH_DIM_RW_SPEC_VAR_CONST) \
	_(1778, ZEND_FETCH_DIM_RW_SPEC_VAR_TMPVAR) \
	_(1779, ZEND_FETCH_DIM_RW_SPEC_VAR_TMPVAR) \
	_(1780, ZEND_FETCH_DIM_RW_SPEC_VAR_UNUSED) \
	_(1781, ZEND_FETCH_DIM_RW_SPEC_VAR_CV) \
	_(1787, ZEND_FETCH_DIM_RW_SPEC_CV_CONST) \
	_(1788, ZEND_FETCH_DIM_RW_SPEC_CV_TMPVAR) \
	_(1789, ZEND_FETCH_DIM_RW_SPEC_CV_TMPVAR) \
	_(1790, ZEND_FETCH_DIM_RW_SPEC_CV_UNUSED) \
	_(1791, ZEND_FETCH_DIM_RW_SPEC_CV_CV) \
	_(1802, ZEND_FETCH_OBJ_RW_SPEC_VAR_CONST) \
	_(1803, ZEND_FETCH_OBJ_RW_SPEC_VAR_TMPVAR) \
	_(1804, ZEND_FETCH_OBJ_RW_SPEC_VAR_TMPVAR) \
	_(1806, ZEND_FETCH_OBJ_RW_SPEC_VAR_CV) \
	_(1807, ZEND_FETCH_OBJ_RW_SPEC_UNUSED_CONST) \
	_(1808, ZEND_FETCH_OBJ_RW_SPEC_UNUSED_TMPVAR) \
	_(1809, ZEND_FETCH_OBJ_RW_SPEC_UNUSED_TMPVAR) \
	_(1811, ZEND_FETCH_OBJ_RW_SPEC_UNUSED_CV) \
	_(1812, ZEND_FETCH_OBJ_RW_SPEC_CV_CONST) \
	_(1813, ZEND_FETCH_OBJ_RW_SPEC_CV_TMPVAR) \
	_(1814, ZEND_FETCH_OBJ_RW_SPEC_CV_TMPVAR) \
	_(1816, ZEND_FETCH_OBJ_RW_SPEC_CV_CV) \
	_(1817, ZEND_FETCH_IS_SPEC_CONST_UNUSED) \
	_(1818, ZEND_FETCH_IS_SPEC_TMPVAR_UNUSED) \
	_(1819, ZEND_FETCH_IS_SPEC_TMPVAR_UNUSED) \
	_(1821, ZEND_FETCH_IS_SPEC_CV_UNUSED) \
	_(1822, ZEND_FETCH_DIM_IS_SPEC_CONST_CONST) \
	_(1823, ZEND_FETCH_DIM_IS_SPEC_CONST_TMPVAR) \
	_(1824, ZEND_FETCH_DIM_IS_SPEC_CONST_TMPVAR) \
	_(1826, ZEND_FETCH_DIM_IS_SPEC_CONST_CV) \
	_(1827, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_CONST) \
	_(1828, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_TMPVAR) \
	_(1829, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_TMPVAR) \
	_(1831, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_CV) \
	_(1832, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_CONST) \
	_(1833, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_TMPVAR) \
	_(1834, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_TMPVAR) \
	_(1836, ZEND_FETCH_DIM_IS_SPEC_TMPVAR_CV) \
	_(1842, ZEND_FETCH_DIM_IS_SPEC_CV_CONST) \
	_(1843, ZEND_FETCH_DIM_IS_SPEC_CV_TMPVAR) \
	_(1844, ZEND_FETCH_DIM_IS_SPEC_CV_TMPVAR) \
	_(1846, ZEND_FETCH_DIM_IS_SPEC_CV_CV) \
	_(1847, ZEND_FETCH_OBJ_IS_SPEC_CONST_CONST) \
	_(1848, ZEND_FETCH_OBJ_IS_SPEC_CONST_TMPVAR) \
	_(1849, ZEND_FETCH_OBJ_IS_SPEC_CONST_TMPVAR) \
	_(1851, ZEND_FETCH_OBJ_IS_SPEC_CONST_CV) \
	_(1852, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_CONST) \
	_(1853, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_TMPVAR) \
	_(1854, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_TMPVAR) \
	_(1856, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_CV) \
	_(1857, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_CONST) \
	_(1858, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_TMPVAR) \
	_(1859, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_TMPVAR) \
	_(1861, ZEND_FETCH_OBJ_IS_SPEC_TMPVAR_CV) \
	_(1862, ZEND_FETCH_OBJ_IS_SPEC_UNUSED_CONST) \
	_(1863, ZEND_FETCH_OBJ_IS_SPEC_UNUSED_TMPVAR) \
	_(1864, ZEND_FETCH_OBJ_IS_SPEC_UNUSED_TMPVAR) \
	_(1866, ZEND_FETCH_OBJ_IS_SPEC_UNUSED_CV) \
	_(1867, ZEND_FETCH_OBJ_IS_SPEC_CV_CONST) \
	_(1868, ZEND_FETCH_OBJ_IS_SPEC_CV_TMPVAR) \
	_(1869, ZEND_FETCH_OBJ_IS_SPEC_CV_TMPVAR) \
	_(1871, ZEND_FETCH_OBJ_IS_SPEC_CV_CV) \
	_(1872, ZEND_FETCH_FUNC_ARG_SPEC_CONST_UNUSED) \
	_(1873, ZEND_FETCH_FUNC_ARG_SPEC_TMPVAR_UNUSED) \
	_(1874, ZEND_FETCH_FUNC_ARG_SPEC_TMPVAR_UNUSED) \
	_(1876, ZEND_FETCH_FUNC_ARG_SPEC_CV_UNUSED) \
	_(1877, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CONST_CONST) \
	_(1878, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CONST_TMPVAR) \
	_(1879, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CONST_TMPVAR) \
	_(1880, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CONST_UNUSED) \
	_(1881, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CONST_CV) \
	_(1882, ZEND_FETCH_DIM_FUNC_ARG_SPEC_TMP_CONST) \
	_(1883, ZEND_FETCH_DIM_FUNC_ARG_SPEC_TMP_TMPVAR) \
	_(1884, ZEND_FETCH_DIM_FUNC_ARG_SPEC_TMP_TMPVAR) \
	_(1885, ZEND_FETCH_DIM_FUNC_ARG_SPEC_TMP_UNUSED) \
	_(1886, ZEND_FETCH_DIM_FUNC_ARG_SPEC_TMP_CV) \
	_(1887, ZEND_FETCH_DIM_FUNC_ARG_SPEC_VAR_CONST) \
	_(1888, ZEND_FETCH_DIM_FUNC_ARG_SPEC_VAR_TMPVAR) \
	_(1889, ZEND_FETCH_DIM_FUNC_ARG_SPEC_VAR_TMPVAR) \
	_(1890, ZEND_FETCH_DIM_FUNC_ARG_SPEC_VAR_UNUSED) \
	_(1891, ZEND_FETCH_DIM_FUNC_ARG_SPEC_VAR_CV) \
	_(1897, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CV_CONST) \
	_(1898, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CV_TMPVAR) \
	_(1899, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CV_TMPVAR) \
	_(1900, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CV_UNUSED) \
	_(1901, ZEND_FETCH_DIM_FUNC_ARG_SPEC_CV_CV) \
	_(1902, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CONST_CONST) \
	_(1903, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CONST_TMPVAR) \
	_(1904, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CONST_TMPVAR) \
	_(1906, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CONST_CV) \
	_(1907, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_TMP_CONST) \
	_(1908, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_TMP_TMPVAR) \
	_(1909, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_TMP_TMPVAR) \
	_(1911, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_TMP_CV) \
	_(1912, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_VAR_CONST) \
	_(1913, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_VAR_TMPVAR) \
	_(1914, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_VAR_TMPVAR) \
	_(1916, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_VAR_CV) \
	_(1917, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_UNUSED_CONST) \
	_(1918, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_UNUSED_TMPVAR) \
	_(1919, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_UNUSED_TMPVAR) \
	_(1921, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_UNUSED_CV) \
	_(1922, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CV_CONST) \
	_(1923, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CV_TMPVAR) \
	_(1924, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CV_TMPVAR) \
	_(1926, ZEND_FETCH_OBJ_FUNC_ARG_SPEC_CV_CV) \
	_(1927, ZEND_FETCH_UNSET_SPEC_CONST_UNUSED) \
	_(1928, ZEND_FETCH_UNSET_SPEC_TMPVAR_UNUSED) \
	_(1929, ZEND_FETCH_UNSET_SPEC_TMPVAR_UNUSED) \
	_(1931, ZEND_FETCH_UNSET_SPEC_CV_UNUSED) \
	_(1942, ZEND_FETCH_DIM_UNSET_SPEC_VAR_CONST) \
	_(1943, ZEND_FETCH_DIM_UNSET_SPEC_VAR_TMPVAR) \
	_(1944, ZEND_FETCH_DIM_UNSET_SPEC_VAR_TMPVAR) \
	_(1946, ZEND_FETCH_DIM_UNSET_SPEC_VAR_CV) \
	_(1952, ZEND_FETCH_DIM_UNSET_SPEC_CV_CONST) \
	_(1953, ZEND_FETCH_DIM_UNSET_SPEC_CV_TMPVAR) \
	_(1954, ZEND_FETCH_DIM_UNSET_SPEC_CV_TMPVAR) \
	_(1956, ZEND_FETCH_DIM_UNSET_SPEC_CV_CV) \
	_(1967, ZEND_FETCH_OBJ_UNSET_SPEC_VAR_CONST) \
	_(1968, ZEND_FETCH_OBJ_UNSET_SPEC_VAR_TMPVAR) \
	_(1969, ZEND_FETCH_OBJ_UNSET_SPEC_VAR_TMPVAR) \
	_(1971, ZEND_FETCH_OBJ_UNSET_SPEC_VAR_CV) \
	_(1972, ZEND_FETCH_OBJ_UNSET_SPEC_UNUSED_CONST) \
	_(1973, ZEND_FETCH_OBJ_UNSET_SPEC_UNUSED_TMPVAR) \
	_(1974, ZEND_FETCH_OBJ_UNSET_SPEC_UNUSED_TMPVAR) \
	_(1976, ZEND_FETCH_OBJ_UNSET_SPEC_UNUSED_CV) \
	_(1977, ZEND_FETCH_OBJ_UNSET_SPEC_CV_CONST) \
	_(1978, ZEND_FETCH_OBJ_UNSET_SPEC_CV_TMPVAR) \
	_(1979, ZEND_FETCH_OBJ_UNSET_SPEC_CV_TMPVAR) \
	_(1981, ZEND_FETCH_OBJ_UNSET_SPEC_CV_CV) \
	_(1982, ZEND_FETCH_LIST_R_SPEC_CONST_CONST) \
	_(1983, ZEND_FETCH_LIST_R_SPEC_CONST_TMPVAR) \
	_(1984, ZEND_FETCH_LIST_R_SPEC_CONST_TMPVAR) \
	_(1986, ZEND_FETCH_LIST_R_SPEC_CONST_CV) \
	_(1987, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CONST) \
	_(1988, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(1989, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(1991, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CV) \
	_(1992, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CONST) \
	_(1993, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(1994, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(1996, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CV) \
	_(2002, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CONST) \
	_(2003, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(2004, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_TMPVAR) \
	_(2006, ZEND_FETCH_LIST_R_SPEC_TMPVARCV_CV) \
	_(2007, ZEND_FETCH_CONSTANT_SPEC_UNUSED_CONST) \
	_(2008, ZEND_CHECK_FUNC_ARG_SPEC_UNUSED) \
	_(2009, ZEND_CHECK_FUNC_ARG_SPEC_UNUSED_QUICK) \
	_(2010, ZEND_EXT_STMT_SPEC) \
	_(2011, ZEND_EXT_FCALL_BEGIN_SPEC) \
	_(2012, ZEND_EXT_FCALL_END_SPEC) \
	_(2013, ZEND_EXT_NOP_SPEC) \
	_(2014, ZEND_TICKS_SPEC) \
	_(2015, ZEND_SEND_VAR_NO_REF_SPEC_VAR) \
	_(2016, ZEND_CATCH_SPEC_CONST) \
	_(2017, ZEND_THROW_SPEC_CONST) \
	_(2018, ZEND_THROW_SPEC_TMP) \
	_(2019, ZEND_THROW_SPEC_VAR) \
	_(2021, ZEND_THROW_SPEC_CV) \
	_(2022, ZEND_FETCH_CLASS_SPEC_UNUSED_CONST) \
	_(2023, ZEND_FETCH_CLASS_SPEC_UNUSED_TMPVAR) \
	_(2024, ZEND_FETCH_CLASS_SPEC_UNUSED_TMPVAR) \
	_(2025, ZEND_FETCH_CLASS_SPEC_UNUSED_UNUSED) \
	_(2026, ZEND_FETCH_CLASS_SPEC_UNUSED_CV) \
	_(2027, ZEND_CLONE_SPEC_CONST) \
	_(2028, ZEND_CLONE_SPEC_TMPVAR) \
	_(2029, ZEND_CLONE_SPEC_TMPVAR) \
	_(2030, ZEND_CLONE_SPEC_UNUSED) \
	_(2031, ZEND_CLONE_SPEC_CV) \
	_(2032, ZEND_RETURN_BY_REF_SPEC_CONST) \
	_(2033, ZEND_RETURN_BY_REF_SPEC_TMP) \
	_(2034, ZEND_RETURN_BY_REF_SPEC_VAR) \
	_(2036, ZEND_RETURN_BY_REF_SPEC_CV) \
	_(2037, ZEND_INIT_METHOD_CALL_SPEC_CONST_CONST) \
	_(2038, ZEND_INIT_METHOD_CALL_SPEC_CONST_TMPVAR) \
	_(2039, ZEND_INIT_METHOD_CALL_SPEC_CONST_TMPVAR) \
	_(2041, ZEND_INIT_METHOD_CALL_SPEC_CONST_CV) \
	_(2042, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_CONST) \
	_(2043, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_TMPVAR) \
	_(2044, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_TMPVAR) \
	_(2046, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_CV) \
	_(2047, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_CONST) \
	_(2048, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_TMPVAR) \
	_(2049, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_TMPVAR) \
	_(2051, ZEND_INIT_METHOD_CALL_SPEC_TMPVAR_CV) \
	_(2052, ZEND_INIT_METHOD_CALL_SPEC_UNUSED_CONST) \
	_(2053, ZEND_INIT_METHOD_CALL_SPEC_UNUSED_TMPVAR) \
	_(2054, ZEND_INIT_METHOD_CALL_SPEC_UNUSED_TMPVAR) \
	_(2056, ZEND_INIT_METHOD_CALL_SPEC_UNUSED_CV) \
	_(2057, ZEND_INIT_METHOD_CALL_SPEC_CV_CONST) \
	_(2058, ZEND_INIT_METHOD_CALL_SPEC_CV_TMPVAR) \
	_(2059, ZEND_INIT_METHOD_CALL_SPEC_CV_TMPVAR) \
	_(2061, ZEND_INIT_METHOD_CALL_SPEC_CV_CV) \
	_(2062, ZEND_INIT_STATIC_METHOD_CALL_SPEC_CONST_CONST) \
	_(2063, ZEND_INIT_STATIC_METHOD_CALL_SPEC_CONST_TMPVAR) \
	_(2064, ZEND_INIT_STATIC_METHOD_CALL_SPEC_CONST_TMPVAR) \
	_(2065, ZEND_INIT_STATIC_METHOD_CALL_SPEC_CONST_UNUSED) \
	_(2066, ZEND_INIT_STATIC_METHOD_CALL_SPEC_CONST_CV) \
	_(2072, ZEND_INIT_STATIC_METHOD_CALL_SPEC_VAR_CONST) \
	_(2073, ZEND_INIT_STATIC_METHOD_CALL_SPEC_VAR_TMPVAR) \
	_(2074, ZEND_INIT_STATIC_METHOD_CALL_SPEC_VAR_TMPVAR) \
	_(2075, ZEND_INIT_STATIC_METHOD_CALL_SPEC_VAR_UNUSED) \
	_(2076, ZEND_INIT_STATIC_METHOD_CALL_SPEC_VAR_CV) \
	_(2077, ZEND_INIT_STATIC_METHOD_CALL_SPEC_UNUSED_CONST) \
	_(2078, ZEND_INIT_STATIC_METHOD_CALL_SPEC_UNUSED_TMPVAR) \
	_(2079, ZEND_INIT_STATIC_METHOD_CALL_SPEC_UNUSED_TMPVAR) \
	_(2080, ZEND_INIT_STATIC_METHOD_CALL_SPEC_UNUSED_UNUSED) \
	_(2081, ZEND_INIT_STATIC_METHOD_CALL_SPEC_UNUSED_CV) \
	_(2087, ZEND_ISSET_ISEMPTY_VAR_SPEC_CONST_UNUSED) \
	_(2088, ZEND_ISSET_ISEMPTY_VAR_SPEC_TMPVAR_UNUSED) \
	_(2089, ZEND_ISSET_ISEMPTY_VAR_SPEC_TMPVAR_UNUSED) \
	_(2091, ZEND_ISSET_ISEMPTY_VAR_SPEC_CV_UNUSED) \
	_(2092, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CONST_CONST) \
	_(2093, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CONST_TMPVAR) \
	_(2094, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CONST_TMPVAR) \
	_(2096, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CONST_CV) \
	_(2097, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_CONST) \
	_(2098, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2099, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2101, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_CV) \
	_(2102, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_CONST) \
	_(2103, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2104, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2106, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_TMPVAR_CV) \
	_(2112, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CV_CONST) \
	_(2113, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CV_TMPVAR) \
	_(2114, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CV_TMPVAR) \
	_(2116, ZEND_ISSET_ISEMPTY_DIM_OBJ_SPEC_CV_CV) \
	_(2117, ZEND_SEND_VAL_EX_SPEC_CONST) \
	_(2118, ZEND_SEND_VAL_EX_SPEC_CONST_QUICK) \
	_(2119, ZEND_SEND_VAL_EX_SPEC_TMP) \
	_(2120, ZEND_SEND_VAL_EX_SPEC_TMP_QUICK) \
	_(2129, ZEND_SEND_VAR_SPEC_VAR) \
	_(2131, ZEND_SEND_VAR_SPEC_CV) \
	_(2132, ZEND_INIT_USER_CALL_SPEC_CONST_CONST) \
	_(2133, ZEND_INIT_USER_CALL_SPEC_CONST_TMPVAR) \
	_(2134, ZEND_INIT_USER_CALL_SPEC_CONST_TMPVAR) \
	_(2136, ZEND_INIT_USER_CALL_SPEC_CONST_CV) \
	_(2137, ZEND_SEND_ARRAY_SPEC) \
	_(2138, ZEND_SEND_USER_SPEC_CONST) \
	_(2139, ZEND_SEND_USER_SPEC_TMP) \
	_(2140, ZEND_SEND_USER_SPEC_VAR) \
	_(2142, ZEND_SEND_USER_SPEC_CV) \
	_(2143, ZEND_STRLEN_SPEC_CONST) \
	_(2144, ZEND_STRLEN_SPEC_TMPVAR) \
	_(2145, ZEND_STRLEN_SPEC_TMPVAR) \
	_(2147, ZEND_STRLEN_SPEC_CV) \
	_(2148, ZEND_DEFINED_SPEC_CONST) \
	_(2149, ZEND_TYPE_CHECK_SPEC_CONST) \
	_(2150, ZEND_TYPE_CHECK_SPEC_TMPVAR) \
	_(2151, ZEND_TYPE_CHECK_SPEC_TMPVAR) \
	_(2153, ZEND_TYPE_CHECK_SPEC_CV) \
	_(2154, ZEND_VERIFY_RETURN_TYPE_SPEC_CONST_UNUSED) \
	_(2155, ZEND_VERIFY_RETURN_TYPE_SPEC_TMP_UNUSED) \
	_(2156, ZEND_VERIFY_RETURN_TYPE_SPEC_VAR_UNUSED) \
	_(2157, ZEND_VERIFY_RETURN_TYPE_SPEC_UNUSED_UNUSED) \
	_(2158, ZEND_VERIFY_RETURN_TYPE_SPEC_CV_UNUSED) \
	_(2159, ZEND_FE_RESET_RW_SPEC_CONST) \
	_(2160, ZEND_FE_RESET_RW_SPEC_TMP) \
	_(2161, ZEND_FE_RESET_RW_SPEC_VAR) \
	_(2163, ZEND_FE_RESET_RW_SPEC_CV) \
	_(2164, ZEND_FE_FETCH_RW_SPEC_VAR) \
	_(2165, ZEND_FE_FREE_SPEC_TMPVAR) \
	_(2166, ZEND_INIT_DYNAMIC_CALL_SPEC_CONST) \
	_(2167, ZEND_INIT_DYNAMIC_CALL_SPEC_TMPVAR) \
	_(2168, ZEND_INIT_DYNAMIC_CALL_SPEC_TMPVAR) \
	_(2170, ZEND_INIT_DYNAMIC_CALL_SPEC_CV) \
	_(2171, ZEND_DO_ICALL_SPEC_RETVAL_UNUSED) \
	_(2172, ZEND_DO_ICALL_SPEC_RETVAL_USED) \
	_(2173, ZEND_DO_UCALL_SPEC_RETVAL_UNUSED) \
	_(2174, ZEND_DO_UCALL_SPEC_RETVAL_USED) \
	_(2175, ZEND_DO_FCALL_BY_NAME_SPEC_RETVAL_UNUSED) \
	_(2176, ZEND_DO_FCALL_BY_NAME_SPEC_RETVAL_USED) \
	_(2187, ZEND_PRE_INC_OBJ_SPEC_VAR_CONST) \
	_(2188, ZEND_PRE_INC_OBJ_SPEC_VAR_TMPVAR) \
	_(2189, ZEND_PRE_INC_OBJ_SPEC_VAR_TMPVAR) \
	_(2191, ZEND_PRE_INC_OBJ_SPEC_VAR_CV) \
	_(2192, ZEND_PRE_INC_OBJ_SPEC_UNUSED_CONST) \
	_(2193, ZEND_PRE_INC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2194, ZEND_PRE_INC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2196, ZEND_PRE_INC_OBJ_SPEC_UNUSED_CV) \
	_(2197, ZEND_PRE_INC_OBJ_SPEC_CV_CONST) \
	_(2198, ZEND_PRE_INC_OBJ_SPEC_CV_TMPVAR) \
	_(2199, ZEND_PRE_INC_OBJ_SPEC_CV_TMPVAR) \
	_(2201, ZEND_PRE_INC_OBJ_SPEC_CV_CV) \
	_(2212, ZEND_PRE_DEC_OBJ_SPEC_VAR_CONST) \
	_(2213, ZEND_PRE_DEC_OBJ_SPEC_VAR_TMPVAR) \
	_(2214, ZEND_PRE_DEC_OBJ_SPEC_VAR_TMPVAR) \
	_(2216, ZEND_PRE_DEC_OBJ_SPEC_VAR_CV) \
	_(2217, ZEND_PRE_DEC_OBJ_SPEC_UNUSED_CONST) \
	_(2218, ZEND_PRE_DEC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2219, ZEND_PRE_DEC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2221, ZEND_PRE_DEC_OBJ_SPEC_UNUSED_CV) \
	_(2222, ZEND_PRE_DEC_OBJ_SPEC_CV_CONST) \
	_(2223, ZEND_PRE_DEC_OBJ_SPEC_CV_TMPVAR) \
	_(2224, ZEND_PRE_DEC_OBJ_SPEC_CV_TMPVAR) \
	_(2226, ZEND_PRE_DEC_OBJ_SPEC_CV_CV) \
	_(2237, ZEND_POST_INC_OBJ_SPEC_VAR_CONST) \
	_(2238, ZEND_POST_INC_OBJ_SPEC_VAR_TMPVAR) \
	_(2239, ZEND_POST_INC_OBJ_SPEC_VAR_TMPVAR) \
	_(2241, ZEND_POST_INC_OBJ_SPEC_VAR_CV) \
	_(2242, ZEND_POST_INC_OBJ_SPEC_UNUSED_CONST) \
	_(2243, ZEND_POST_INC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2244, ZEND_POST_INC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2246, ZEND_POST_INC_OBJ_SPEC_UNUSED_CV) \
	_(2247, ZEND_POST_INC_OBJ_SPEC_CV_CONST) \
	_(2248, ZEND_POST_INC_OBJ_SPEC_CV_TMPVAR) \
	_(2249, ZEND_POST_INC_OBJ_SPEC_CV_TMPVAR) \
	_(2251, ZEND_POST_INC_OBJ_SPEC_CV_CV) \
	_(2262, ZEND_POST_DEC_OBJ_SPEC_VAR_CONST) \
	_(2263, ZEND_POST_DEC_OBJ_SPEC_VAR_TMPVAR) \
	_(2264, ZEND_POST_DEC_OBJ_SPEC_VAR_TMPVAR) \
	_(2266, ZEND_POST_DEC_OBJ_SPEC_VAR_CV) \
	_(2267, ZEND_POST_DEC_OBJ_SPEC_UNUSED_CONST) \
	_(2268, ZEND_POST_DEC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2269, ZEND_POST_DEC_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2271, ZEND_POST_DEC_OBJ_SPEC_UNUSED_CV) \
	_(2272, ZEND_POST_DEC_OBJ_SPEC_CV_CONST) \
	_(2273, ZEND_POST_DEC_OBJ_SPEC_CV_TMPVAR) \
	_(2274, ZEND_POST_DEC_OBJ_SPEC_CV_TMPVAR) \
	_(2276, ZEND_POST_DEC_OBJ_SPEC_CV_CV) \
	_(2327, ZEND_ASSIGN_OBJ_SPEC_VAR_CONST_OP_DATA_CONST) \
	_(2328, ZEND_ASSIGN_OBJ_SPEC_VAR_CONST_OP_DATA_TMP) \
	_(2329, ZEND_ASSIGN_OBJ_SPEC_VAR_CONST_OP_DATA_VAR) \
	_(2331, ZEND_ASSIGN_OBJ_SPEC_VAR_CONST_OP_DATA_CV) \
	_(2332, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_CONST) \
	_(2333, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_TMP) \
	_(2334, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_VAR) \
	_(2336, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_CV) \
	_(2337, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_CONST) \
	_(2338, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_TMP) \
	_(2339, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_VAR) \
	_(2341, ZEND_ASSIGN_OBJ_SPEC_VAR_TMPVAR_OP_DATA_CV) \
	_(2347, ZEND_ASSIGN_OBJ_SPEC_VAR_CV_OP_DATA_CONST) \
	_(2348, ZEND_ASSIGN_OBJ_SPEC_VAR_CV_OP_DATA_TMP) \
	_(2349, ZEND_ASSIGN_OBJ_SPEC_VAR_CV_OP_DATA_VAR) \
	_(2351, ZEND_ASSIGN_OBJ_SPEC_VAR_CV_OP_DATA_CV) \
	_(2352, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CONST_OP_DATA_CONST) \
	_(2353, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CONST_OP_DATA_TMP) \
	_(2354, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CONST_OP_DATA_VAR) \
	_(2356, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CONST_OP_DATA_CV) \
	_(2357, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_CONST) \
	_(2358, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_TMP) \
	_(2359, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_VAR) \
	_(2361, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_CV) \
	_(2362, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_CONST) \
	_(2363, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_TMP) \
	_(2364, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_VAR) \
	_(2366, ZEND_ASSIGN_OBJ_SPEC_UNUSED_TMPVAR_OP_DATA_CV) \
	_(2372, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CV_OP_DATA_CONST) \
	_(2373, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CV_OP_DATA_TMP) \
	_(2374, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CV_OP_DATA_VAR) \
	_(2376, ZEND_ASSIGN_OBJ_SPEC_UNUSED_CV_OP_DATA_CV) \
	_(2377, ZEND_ASSIGN_OBJ_SPEC_CV_CONST_OP_DATA_CONST) \
	_(2378, ZEND_ASSIGN_OBJ_SPEC_CV_CONST_OP_DATA_TMP) \
	_(2379, ZEND_ASSIGN_OBJ_SPEC_CV_CONST_OP_DATA_VAR) \
	_(2381, ZEND_ASSIGN_OBJ_SPEC_CV_CONST_OP_DATA_CV) \
	_(2382, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_CONST) \
	_(2383, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_TMP) \
	_(2384, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_VAR) \
	_(2386, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_CV) \
	_(2387, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_CONST) \
	_(2388, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_TMP) \
	_(2389, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_VAR) \
	_(2391, ZEND_ASSIGN_OBJ_SPEC_CV_TMPVAR_OP_DATA_CV) \
	_(2397, ZEND_ASSIGN_OBJ_SPEC_CV_CV_OP_DATA_CONST) \
	_(2398, ZEND_ASSIGN_OBJ_SPEC_CV_CV_OP_DATA_TMP) \
	_(2399, ZEND_ASSIGN_OBJ_SPEC_CV_CV_OP_DATA_VAR) \
	_(2401, ZEND_ASSIGN_OBJ_SPEC_CV_CV_OP_DATA_CV) \
	_(2408, ZEND_INSTANCEOF_SPEC_TMPVAR_CONST) \
	_(2410, ZEND_INSTANCEOF_SPEC_TMPVAR_VAR) \
	_(2411, ZEND_INSTANCEOF_SPEC_TMPVAR_UNUSED) \
	_(2413, ZEND_INSTANCEOF_SPEC_TMPVAR_CONST) \
	_(2415, ZEND_INSTANCEOF_SPEC_TMPVAR_VAR) \
	_(2416, ZEND_INSTANCEOF_SPEC_TMPVAR_UNUSED) \
	_(2423, ZEND_INSTANCEOF_SPEC_CV_CONST) \
	_(2425, ZEND_INSTANCEOF_SPEC_CV_VAR) \
	_(2426, ZEND_INSTANCEOF_SPEC_CV_UNUSED) \
	_(2428, ZEND_DECLARE_CLASS_SPEC_CONST) \
	_(2429, ZEND_DECLARE_INHERITED_CLASS_SPEC_CONST_CONST) \
	_(2430, ZEND_DECLARE_FUNCTION_SPEC) \
	_(2431, ZEND_YIELD_FROM_SPEC_CONST) \
	_(2432, ZEND_YIELD_FROM_SPEC_TMP) \
	_(2433, ZEND_YIELD_FROM_SPEC_VAR) \
	_(2435, ZEND_YIELD_FROM_SPEC_CV) \
	_(2436, ZEND_DECLARE_CONST_SPEC_CONST_CONST) \
	_(2437, ZEND_ADD_INTERFACE_SPEC_CONST) \
	_(2438, ZEND_DECLARE_INHERITED_CLASS_DELAYED_SPEC_CONST_CONST) \
	_(2439, ZEND_VERIFY_ABSTRACT_CLASS_SPEC) \
	_(2490, ZEND_ASSIGN_DIM_SPEC_VAR_CONST_OP_DATA_CONST) \
	_(2491, ZEND_ASSIGN_DIM_SPEC_VAR_CONST_OP_DATA_TMP) \
	_(2492, ZEND_ASSIGN_DIM_SPEC_VAR_CONST_OP_DATA_VAR) \
	_(2494, ZEND_ASSIGN_DIM_SPEC_VAR_CONST_OP_DATA_CV) \
	_(2495, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_CONST) \
	_(2496, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_TMP) \
	_(2497, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_VAR) \
	_(2499, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_CV) \
	_(2500, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_CONST) \
	_(2501, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_TMP) \
	_(2502, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_VAR) \
	_(2504, ZEND_ASSIGN_DIM_SPEC_VAR_TMPVAR_OP_DATA_CV) \
	_(2505, ZEND_ASSIGN_DIM_SPEC_VAR_UNUSED_OP_DATA_CONST) \
	_(2506, ZEND_ASSIGN_DIM_SPEC_VAR_UNUSED_OP_DATA_TMP) \
	_(2507, ZEND_ASSIGN_DIM_SPEC_VAR_UNUSED_OP_DATA_VAR) \
	_(2509, ZEND_ASSIGN_DIM_SPEC_VAR_UNUSED_OP_DATA_CV) \
	_(2510, ZEND_ASSIGN_DIM_SPEC_VAR_CV_OP_DATA_CONST) \
	_(2511, ZEND_ASSIGN_DIM_SPEC_VAR_CV_OP_DATA_TMP) \
	_(2512, ZEND_ASSIGN_DIM_SPEC_VAR_CV_OP_DATA_VAR) \
	_(2514, ZEND_ASSIGN_DIM_SPEC_VAR_CV_OP_DATA_CV) \
	_(2540, ZEND_ASSIGN_DIM_SPEC_CV_CONST_OP_DATA_CONST) \
	_(2541, ZEND_ASSIGN_DIM_SPEC_CV_CONST_OP_DATA_TMP) \
	_(2542, ZEND_ASSIGN_DIM_SPEC_CV_CONST_OP_DATA_VAR) \
	_(2544, ZEND_ASSIGN_DIM_SPEC_CV_CONST_OP_DATA_CV) \
	_(2545, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_CONST) \
	_(2546, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_TMP) \
	_(2547, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_VAR) \
	_(2549, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_CV) \
	_(2550, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_CONST) \
	_(2551, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_TMP) \
	_(2552, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_VAR) \
	_(2554, ZEND_ASSIGN_DIM_SPEC_CV_TMPVAR_OP_DATA_CV) \
	_(2555, ZEND_ASSIGN_DIM_SPEC_CV_UNUSED_OP_DATA_CONST) \
	_(2556, ZEND_ASSIGN_DIM_SPEC_CV_UNUSED_OP_DATA_TMP) \
	_(2557, ZEND_ASSIGN_DIM_SPEC_CV_UNUSED_OP_DATA_VAR) \
	_(2559, ZEND_ASSIGN_DIM_SPEC_CV_UNUSED_OP_DATA_CV) \
	_(2560, ZEND_ASSIGN_DIM_SPEC_CV_CV_OP_DATA_CONST) \
	_(2561, ZEND_ASSIGN_DIM_SPEC_CV_CV_OP_DATA_TMP) \
	_(2562, ZEND_ASSIGN_DIM_SPEC_CV_CV_OP_DATA_VAR) \
	_(2564, ZEND_ASSIGN_DIM_SPEC_CV_CV_OP_DATA_CV) \
	_(2565, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CONST_CONST) \
	_(2566, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CONST_TMPVAR) \
	_(2567, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CONST_TMPVAR) \
	_(2569, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CONST_CV) \
	_(2570, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_CONST) \
	_(2571, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2572, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2574, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_CV) \
	_(2575, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_CONST) \
	_(2576, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2577, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_TMPVAR) \
	_(2579, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_TMPVAR_CV) \
	_(2580, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_UNUSED_CONST) \
	_(2581, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2582, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_UNUSED_TMPVAR) \
	_(2584, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_UNUSED_CV) \
	_(2585, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CV_CONST) \
	_(2586, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CV_TMPVAR) \
	_(2587, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CV_TMPVAR) \
	_(2589, ZEND_ISSET_ISEMPTY_PROP_OBJ_SPEC_CV_CV) \
	_(2590, ZEND_HANDLE_EXCEPTION_SPEC) \
	_(2591, ZEND_USER_OPCODE_SPEC) \
	_(2592, ZEND_ASSERT_CHECK_SPEC) \
	_(2593, ZEND_JMP_SET_SPEC_CONST) \
	_(2594, ZEND_JMP_SET_SPEC_TMP) \
	_(2595, ZEND_JMP_SET_SPEC_VAR) \
	_(2597, ZEND_JMP_SET_SPEC_CV) \
	_(2598, ZEND_DECLARE_LAMBDA_FUNCTION_SPEC_CONST_UNUSED) \
	_(2599, ZEND_ADD_TRAIT_SPEC) \
	_(2600, ZEND_BIND_TRAITS_SPEC) \
	_(2601, ZEND_SEPARATE_SPEC_VAR_UNUSED) \
	_(2602, ZEND_FETCH_CLASS_NAME_SPEC_UNUSED) \
	_(2603, ZEND_CALL_TRAMPOLINE_SPEC) \
	_(2604, ZEND_DISCARD_EXCEPTION_SPEC) \
	_(2605, ZEND_YIELD_SPEC_CONST_CONST) \
	_(2606, ZEND_YIELD_SPEC_CONST_TMP) \
	_(2607, ZEND_YIELD_SPEC_CONST_VAR) \
	_(2608, ZEND_YIELD_SPEC_CONST_UNUSED) \
	_(2609, ZEND_YIELD_SPEC_CONST_CV) \
	_(2610, ZEND_YIELD_SPEC_TMP_CONST) \
	_(2611, ZEND_YIELD_SPEC_TMP_TMP) \
	_(2612, ZEND_YIELD_SPEC_TMP_VAR) \
	_(2613, ZEND_YIELD_SPEC_TMP_UNUSED) \
	_(2614, ZEND_YIELD_SPEC_TMP_CV) \
	_(2615, ZEND_YIELD_SPEC_VAR_CONST) \
	_(2616, ZEND_YIELD_SPEC_VAR_TMP) \
	_(2617, ZEND_YIELD_SPEC_VAR_VAR) \
	_(2618, ZEND_YIELD_SPEC_VAR_UNUSED) \
	_(2619, ZEND_YIELD_SPEC_VAR_CV) \
	_(2620, ZEND_YIELD_SPEC_UNUSED_CONST) \
	_(2621, ZEND_YIELD_SPEC_UNUSED_TMP) \
	_(2622, ZEND_YIELD_SPEC_UNUSED_VAR) \
	_(2623, ZEND_YIELD_SPEC_UNUSED_UNUSED) \
	_(2624, ZEND_YIELD_SPEC_UNUSED_CV) \
	_(2625, ZEND_YIELD_SPEC_CV_CONST) \
	_(2626, ZEND_YIELD_SPEC_CV_TMP) \
	_(2627, ZEND_YIELD_SPEC_CV_VAR) \
	_(2628, ZEND_YIELD_SPEC_CV_UNUSED) \
	_(2629, ZEND_YIELD_SPEC_CV_CV) \
	_(2630, ZEND_GENERATOR_RETURN_SPEC_CONST) \
	_(2631, ZEND_GENERATOR_RETURN_SPEC_TMP) \
	_(2632, ZEND_GENERATOR_RETURN_SPEC_VAR) \
	_(2634, ZEND_GENERATOR_RETURN_SPEC_CV) \
	_(2635, ZEND_FAST_CALL_SPEC) \
	_(2636, ZEND_FAST_RET_SPEC) \
	_(2637, ZEND_RECV_VARIADIC_SPEC_UNUSED) \
	_(2638, ZEND_SEND_UNPACK_SPEC) \
	_(2639, ZEND_POW_SPEC_CONST_CONST) \
	_(2640, ZEND_POW_SPEC_CONST_TMPVAR) \
	_(2641, ZEND_POW_SPEC_CONST_TMPVAR) \
	_(2643, ZEND_POW_SPEC_CONST_CV) \
	_(2644, ZEND_POW_SPEC_TMPVAR_CONST) \
	_(2645, ZEND_POW_SPEC_TMPVAR_TMPVAR) \
	_(2646, ZEND_POW_SPEC_TMPVAR_TMPVAR) \
	_(2648, ZEND_POW_SPEC_TMPVAR_CV) \
	_(2649, ZEND_POW_SPEC_TMPVAR_CONST) \
	_(2650, ZEND_POW_SPEC_TMPVAR_TMPVAR) \
	_(2651, ZEND_POW_SPEC_TMPVAR_TMPVAR) \
	_(2653, ZEND_POW_SPEC_TMPVAR_CV) \
	_(2659, ZEND_POW_SPEC_CV_CONST) \
	_(2660, ZEND_POW_SPEC_CV_TMPVAR) \
	_(2661, ZEND_POW_SPEC_CV_TMPVAR) \
	_(2663, ZEND_POW_SPEC_CV_CV) \
	_(2694, ZEND_ASSIGN_POW_SPEC_VAR_CONST) \
	_(2695, ZEND_ASSIGN_POW_SPEC_VAR_CONST_DIM) \
	_(2696, ZEND_ASSIGN_POW_SPEC_VAR_CONST_OBJ) \
	_(2697, ZEND_ASSIGN_POW_SPEC_VAR_TMPVAR) \
	_(2698, ZEND_ASSIGN_POW_SPEC_VAR_TMPVAR_DIM) \
	_(2699, ZEND_ASSIGN_POW_SPEC_VAR_TMPVAR_OBJ) \
	_(2700, ZEND_ASSIGN_POW_SPEC_VAR_TMPVAR) \
	_(2701, ZEND_ASSIGN_POW_SPEC_VAR_TMPVAR_DIM) \
	_(2702, ZEND_ASSIGN_POW_SPEC_VAR_TMPVAR_OBJ) \
	_(2704, ZEND_ASSIGN_POW_SPEC_VAR_UNUSED_DIM) \
	_(2706, ZEND_ASSIGN_POW_SPEC_VAR_CV) \
	_(2707, ZEND_ASSIGN_POW_SPEC_VAR_CV_DIM) \
	_(2708, ZEND_ASSIGN_POW_SPEC_VAR_CV_OBJ) \
	_(2711, ZEND_ASSIGN_POW_SPEC_UNUSED_CONST_OBJ) \
	_(2714, ZEND_ASSIGN_POW_SPEC_UNUSED_TMPVAR_OBJ) \
	_(2717, ZEND_ASSIGN_POW_SPEC_UNUSED_TMPVAR_OBJ) \
	_(2723, ZEND_ASSIGN_POW_SPEC_UNUSED_CV_OBJ) \
	_(2724, ZEND_ASSIGN_POW_SPEC_CV_CONST) \
	_(2725, ZEND_ASSIGN_POW_SPEC_CV_CONST_DIM) \
	_(2726, ZEND_ASSIGN_POW_SPEC_CV_CONST_OBJ) \
	_(2727, ZEND_ASSIGN_POW_SPEC_CV_TMPVAR) \
	_(2728, ZEND_ASSIGN_POW_SPEC_CV_TMPVAR_DIM) \
	_(2729, ZEND_ASSIGN_POW_SPEC_CV_TMPVAR_OBJ) \
	_(2730, ZEND_ASSIGN_POW_SPEC_CV_TMPVAR) \
	_(2731, ZEND_ASSIGN_POW_SPEC_CV_TMPVAR_DIM) \
	_(2732, ZEND_ASSIGN_POW_SPEC_CV_TMPVAR_OBJ) \
	_(2734, ZEND_ASSIGN_POW_SPEC_CV_UNUSED_DIM) \
	_(2736, ZEND_ASSIGN_POW_SPEC_CV_CV) \
	_(2737, ZEND_ASSIGN_POW_SPEC_CV_CV_DIM) \
	_(2738, ZEND_ASSIGN_POW_SPEC_CV_CV_OBJ) \
	_(2739, ZEND_BIND_GLOBAL_SPEC_CV_CONST) \
	_(2740, ZEND_COALESCE_SPEC_CONST) \
	_(2741, ZEND_COALESCE_SPEC_TMPVAR) \
	_(2742, ZEND_COALESCE_SPEC_TMPVAR) \
	_(2744, ZEND_COALESCE_SPEC_CV) \
	_(2745, ZEND_SPACESHIP_SPEC_CONST_CONST) \
	_(2746, ZEND_SPACESHIP_SPEC_CONST_TMPVAR) \
	_(2747, ZEND_SPACESHIP_SPEC_CONST_TMPVAR) \
	_(2749, ZEND_SPACESHIP_SPEC_CONST_CV) \
	_(2750, ZEND_SPACESHIP_SPEC_TMPVAR_CONST) \
	_(2751, ZEND_SPACESHIP_SPEC_TMPVAR_TMPVAR) \
	_(2752, ZEND_SPACESHIP_SPEC_TMPVAR_TMPVAR) \
	_(2754, ZEND_SPACESHIP_SPEC_TMPVAR_CV) \
	_(2755, ZEND_SPACESHIP_SPEC_TMPVAR_CONST) \
	_(2756, ZEND_SPACESHIP_SPEC_TMPVAR_TMPVAR) \
	_(2757, ZEND_SPACESHIP_SPEC_TMPVAR_TMPVAR) \
	_(2759, ZEND_SPACESHIP_SPEC_TMPVAR_CV) \
	_(2765, ZEND_SPACESHIP_SPEC_CV_CONST) \
	_(2766, ZEND_SPACESHIP_SPEC_CV_TMPVAR) \
	_(2767, ZEND_SPACESHIP_SPEC_CV_TMPVAR) \
	_(2769, ZEND_SPACESHIP_SPEC_CV_CV) \
	_(2770, ZEND_DECLARE_ANON_CLASS_SPEC) \
	_(2771, ZEND_DECLARE_ANON_INHERITED_CLASS_SPEC_CONST_CONST) \
	_(2772, ZEND_FETCH_STATIC_PROP_R_SPEC_CONST_CONST) \
	_(2774, ZEND_FETCH_STATIC_PROP_R_SPEC_CONST_VAR) \
	_(2775, ZEND_FETCH_STATIC_PROP_R_SPEC_CONST_UNUSED) \
	_(2777, ZEND_FETCH_STATIC_PROP_R_SPEC_TMPVAR_CONST) \
	_(2779, ZEND_FETCH_STATIC_PROP_R_SPEC_TMPVAR_VAR) \
	_(2780, ZEND_FETCH_STATIC_PROP_R_SPEC_TMPVAR_UNUSED) \
	_(2782, ZEND_FETCH_STATIC_PROP_R_SPEC_TMPVAR_CONST) \
	_(2784, ZEND_FETCH_STATIC_PROP_R_SPEC_TMPVAR_VAR) \
	_(2785, ZEND_FETCH_STATIC_PROP_R_SPEC_TMPVAR_UNUSED) \
	_(2792, ZEND_FETCH_STATIC_PROP_R_SPEC_CV_CONST) \
	_(2794, ZEND_FETCH_STATIC_PROP_R_SPEC_CV_VAR) \
	_(2795, ZEND_FETCH_STATIC_PROP_R_SPEC_CV_UNUSED) \
	_(2797, ZEND_FETCH_STATIC_PROP_W_SPEC_CONST_CONST) \
	_(2799, ZEND_FETCH_STATIC_PROP_W_SPEC_CONST_VAR) \
	_(2800, ZEND_FETCH_STATIC_PROP_W_SPEC_CONST_UNUSED) \
	_(2802, ZEND_FETCH_STATIC_PROP_W_SPEC_TMPVAR_CONST) \
	_(2804, ZEND_FETCH_STATIC_PROP_W_SPEC_TMPVAR_VAR) \
	_(2805, ZEND_FETCH_STATIC_PROP_W_SPEC_TMPVAR_UNUSED) \
	_(2807, ZEND_FETCH_STATIC_PROP_W_SPEC_TMPVAR_CONST) \
	_(2809, ZEND_FETCH_STATIC_PROP_W_SPEC_TMPVAR_VAR) \
	_(2810, ZEND_FETCH_STATIC_PROP_W_SPEC_TMPVAR_UNUSED) \
	_(2817, ZEND_FETCH_STATIC_PROP_W_SPEC_CV_CONST) \
	_(2819, ZEND_FETCH_STATIC_PROP_W_SPEC_CV_VAR) \
	_(2820, ZEND_FETCH_STATIC_PROP_W_SPEC_CV_UNUSED) \
	_(2822, ZEND_FETCH_STATIC_PROP_RW_SPEC_CONST_CONST) \
	_(2824, ZEND_FETCH_STATIC_PROP_RW_SPEC_CONST_VAR) \
	_(2825, ZEND_FETCH_STATIC_PROP_RW_SPEC_CONST_UNUSED) \
	_(2827, ZEND_FETCH_STATIC_PROP_RW_SPEC_TMPVAR_CONST) \
	_(2829, ZEND_FETCH_STATIC_PROP_RW_SPEC_TMPVAR_VAR) \
	_(2830, ZEND_FETCH_STATIC_PROP_RW_SPEC_TMPVAR_UNUSED) \
	_(2832, ZEND_FETCH_STATIC_PROP_RW_SPEC_TMPVAR_CONST) \
	_(2834, ZEND_FETCH_STATIC_PROP_RW_SPEC_TMPVAR_VAR) \
	_(2835, ZEND_FETCH_STATIC_PROP_RW_SPEC_TMPVAR_UNUSED) \
	_(2842, ZEND_FETCH_STATIC_PROP_RW_SPEC_CV_CONST) \
	_(2844, ZEND_FETCH_STATIC_PROP_RW_SPEC_CV_VAR) \
	_(2845, ZEND_FETCH_STATIC_PROP_RW_SPEC_CV_UNUSED) \
	_(2847, ZEND_FETCH_STATIC_PROP_IS_SPEC_CONST_CONST) \
	_(2849, ZEND_FETCH_STATIC_PROP_IS_SPEC_CONST_VAR) \
	_(2850, ZEND_FETCH_STATIC_PROP_IS_SPEC_CONST_UNUSED) \
	_(2852, ZEND_FETCH_STATIC_PROP_IS_SPEC_TMPVAR_CONST) \
	_(2854, ZEND_FETCH_STATIC_PROP_IS_SPEC_TMPVAR_VAR) \
	_(2855, ZEND_FETCH_STATIC_PROP_IS_SPEC_TMPVAR_UNUSED) \
	_(2857, ZEND_FETCH_STATIC_PROP_IS_SPEC_TMPVAR_CONST) \
	_(2859, ZEND_FETCH_STATIC_PROP_IS_SPEC_TMPVAR_VAR) \
	_(2860, ZEND_FETCH_STATIC_PROP_IS_SPEC_TMPVAR_UNUSED) \
	_(2867, ZEND_FETCH_STATIC_PROP_IS_SPEC_CV_CONST) \
	_(2869, ZEND_FETCH_STATIC_PROP_IS_SPEC_CV_VAR) \
	_(2870, ZEND_FETCH_STATIC_PROP_IS_SPEC_CV_UNUSED) \
	_(2872, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_CONST_CONST) \
	_(2874, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_CONST_VAR) \
	_(2875, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_CONST_UNUSED) \
	_(2877, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_TMPVAR_CONST) \
	_(2879, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_TMPVAR_VAR) \
	_(2880, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_TMPVAR_UNUSED) \
	_(2882, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_TMPVAR_CONST) \
	_(2884, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_TMPVAR_VAR) \
	_(2885, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_TMPVAR_UNUSED) \
	_(2892, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_CV_CONST) \
	_(2894, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_CV_VAR) \
	_(2895, ZEND_FETCH_STATIC_PROP_FUNC_ARG_SPEC_CV_UNUSED) \
	_(2897, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_CONST_CONST) \
	_(2899, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_CONST_VAR) \
	_(2900, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_CONST_UNUSED) \
	_(2902, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_TMPVAR_CONST) \
	_(2904, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_TMPVAR_VAR) \
	_(2905, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_TMPVAR_UNUSED) \
	_(2907, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_TMPVAR_CONST) \
	_(2909, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_TMPVAR_VAR) \
	_(2910, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_TMPVAR_UNUSED) \
	_(2917, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_CV_CONST) \
	_(2919, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_CV_VAR) \
	_(2920, ZEND_FETCH_STATIC_PROP_UNSET_SPEC_CV_UNUSED) \
	_(2922, ZEND_UNSET_STATIC_PROP_SPEC_CONST_CONST) \
	_(2924, ZEND_UNSET_STATIC_PROP_SPEC_CONST_VAR) \
	_(2925, ZEND_UNSET_STATIC_PROP_SPEC_CONST_UNUSED) \
	_(2927, ZEND_UNSET_STATIC_PROP_SPEC_TMPVAR_CONST) \
	_(2929, ZEND_UNSET_STATIC_PROP_SPEC_TMPVAR_VAR) \
	_(2930, ZEND_UNSET_STATIC_PROP_SPEC_TMPVAR_UNUSED) \
	_(2932, ZEND_UNSET_STATIC_PROP_SPEC_TMPVAR_CONST) \
	_(2934, ZEND_UNSET_STATIC_PROP_SPEC_TMPVAR_VAR) \
	_(2935, ZEND_UNSET_STATIC_PROP_SPEC_TMPVAR_UNUSED) \
	_(2942, ZEND_UNSET_STATIC_PROP_SPEC_CV_CONST) \
	_(2944, ZEND_UNSET_STATIC_PROP_SPEC_CV_VAR) \
	_(2945, ZEND_UNSET_STATIC_PROP_SPEC_CV_UNUSED) \
	_(2947, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_CONST_CONST) \
	_(2949, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_CONST_VAR) \
	_(2950, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_CONST_UNUSED) \
	_(2952, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_TMPVAR_CONST) \
	_(2954, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_TMPVAR_VAR) \
	_(2955, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_TMPVAR_UNUSED) \
	_(2957, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_TMPVAR_CONST) \
	_(2959, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_TMPVAR_VAR) \
	_(2960, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_TMPVAR_UNUSED) \
	_(2967, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_CV_CONST) \
	_(2969, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_CV_VAR) \
	_(2970, ZEND_ISSET_ISEMPTY_STATIC_PROP_SPEC_CV_UNUSED) \
	_(2972, ZEND_FETCH_CLASS_CONSTANT_SPEC_CONST_CONST) \
	_(2974, ZEND_FETCH_CLASS_CONSTANT_SPEC_VAR_CONST) \
	_(2975, ZEND_FETCH_CLASS_CONSTANT_SPEC_UNUSED_CONST) \
	_(2977, ZEND_BIND_LEXICAL_SPEC_TMP_CV) \
	_(2978, ZEND_BIND_STATIC_SPEC_CV_CONST) \
	_(2979, ZEND_FETCH_THIS_SPEC_UNUSED_UNUSED) \
	_(2980, ZEND_SEND_FUNC_ARG_SPEC_VAR) \
	_(2981, ZEND_ISSET_ISEMPTY_THIS_SPEC_UNUSED_UNUSED) \
	_(2982, ZEND_SWITCH_LONG_SPEC_CONST_CONST) \
	_(2983, ZEND_SWITCH_LONG_SPEC_TMPVARCV_CONST) \
	_(2984, ZEND_SWITCH_LONG_SPEC_TMPVARCV_CONST) \
	_(2986, ZEND_SWITCH_LONG_SPEC_TMPVARCV_CONST) \
	_(2987, ZEND_SWITCH_STRING_SPEC_CONST_CONST) \
	_(2988, ZEND_SWITCH_STRING_SPEC_TMPVARCV_CONST) \
	_(2989, ZEND_SWITCH_STRING_SPEC_TMPVARCV_CONST) \
	_(2991, ZEND_SWITCH_STRING_SPEC_TMPVARCV_CONST) \
	_(2992, ZEND_IN_ARRAY_SPEC_CONST_CONST) \
	_(2993, ZEND_IN_ARRAY_SPEC_TMP_CONST) \
	_(2994, ZEND_IN_ARRAY_SPEC_VAR_CONST) \
	_(2996, ZEND_IN_ARRAY_SPEC_CV_CONST) \
	_(2997, ZEND_COUNT_SPEC_CONST_UNUSED) \
	_(2998, ZEND_COUNT_SPEC_TMP_UNUSED) \
	_(2999, ZEND_COUNT_SPEC_VAR_UNUSED) \
	_(3001, ZEND_COUNT_SPEC_CV_UNUSED) \
	_(3002, ZEND_GET_CLASS_SPEC_CONST_UNUSED) \
	_(3003, ZEND_GET_CLASS_SPEC_TMP_UNUSED) \
	_(3004, ZEND_GET_CLASS_SPEC_VAR_UNUSED) \
	_(3005, ZEND_GET_CLASS_SPEC_UNUSED_UNUSED) \
	_(3006, ZEND_GET_CLASS_SPEC_CV_UNUSED) \
	_(3007, ZEND_GET_CALLED_CLASS_SPEC_UNUSED_UNUSED) \
	_(3008, ZEND_GET_TYPE_SPEC_CONST_UNUSED) \
	_(3009, ZEND_GET_TYPE_SPEC_TMP_UNUSED) \
	_(3010, ZEND_GET_TYPE_SPEC_VAR_UNUSED) \
	_(3012, ZEND_GET_TYPE_SPEC_CV_UNUSED) \
	_(3013, ZEND_FUNC_NUM_ARGS_SPEC_UNUSED_UNUSED) \
	_(3014, ZEND_FUNC_GET_ARGS_SPEC_CONST_UNUSED) \
	_(3017, ZEND_FUNC_GET_ARGS_SPEC_UNUSED_UNUSED) \
	_(3019, ZEND_UNSET_CV_SPEC_CV_UNUSED) \
	_(3020, ZEND_ISSET_ISEMPTY_CV_SPEC_CV_UNUSED_SET) \
	_(3021, ZEND_ISSET_ISEMPTY_CV_SPEC_CV_UNUSED_EMPTY) \
	_(3022, ZEND_FETCH_LIST_W_SPEC_VAR_CONST) \
	_(3023, ZEND_FETCH_LIST_W_SPEC_VAR_TMPVAR) \
	_(3024, ZEND_FETCH_LIST_W_SPEC_VAR_TMPVAR) \
	_(3026, ZEND_FETCH_LIST_W_SPEC_VAR_CV) \
	_(3027, ZEND_JMP_FORWARD_SPEC) \
	_(3033, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(3034, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3035, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3037, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3038, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(3039, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3040, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3042, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3048, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(3049, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3050, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3052, ZEND_ADD_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3058, ZEND_ADD_LONG_SPEC_TMPVARCV_CONST) \
	_(3059, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3060, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3062, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3063, ZEND_ADD_LONG_SPEC_TMPVARCV_CONST) \
	_(3064, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3065, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3067, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3073, ZEND_ADD_LONG_SPEC_TMPVARCV_CONST) \
	_(3074, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3075, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3077, ZEND_ADD_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3083, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3084, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3085, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3087, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3088, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3089, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3090, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3092, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3098, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3099, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3100, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3102, ZEND_ADD_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3104, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_CONST_TMPVARCV) \
	_(3105, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_CONST_TMPVARCV) \
	_(3107, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_CONST_TMPVARCV) \
	_(3108, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(3109, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3110, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3112, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3113, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(3114, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3115, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3117, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3123, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(3124, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3125, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3127, ZEND_SUB_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3129, ZEND_SUB_LONG_SPEC_CONST_TMPVARCV) \
	_(3130, ZEND_SUB_LONG_SPEC_CONST_TMPVARCV) \
	_(3132, ZEND_SUB_LONG_SPEC_CONST_TMPVARCV) \
	_(3133, ZEND_SUB_LONG_SPEC_TMPVARCV_CONST) \
	_(3134, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3135, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3137, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3138, ZEND_SUB_LONG_SPEC_TMPVARCV_CONST) \
	_(3139, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3140, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3142, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3148, ZEND_SUB_LONG_SPEC_TMPVARCV_CONST) \
	_(3149, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3150, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3152, ZEND_SUB_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3154, ZEND_SUB_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3155, ZEND_SUB_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3157, ZEND_SUB_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3158, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3159, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3160, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3162, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3163, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3164, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3165, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3167, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3173, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3174, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3175, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3177, ZEND_SUB_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3183, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(3184, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3185, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3187, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3188, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(3189, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3190, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3192, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3198, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_CONST) \
	_(3199, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3200, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3202, ZEND_MUL_LONG_NO_OVERFLOW_SPEC_TMPVARCV_TMPVARCV) \
	_(3208, ZEND_MUL_LONG_SPEC_TMPVARCV_CONST) \
	_(3209, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3210, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3212, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3213, ZEND_MUL_LONG_SPEC_TMPVARCV_CONST) \
	_(3214, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3215, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3217, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3223, ZEND_MUL_LONG_SPEC_TMPVARCV_CONST) \
	_(3224, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3225, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3227, ZEND_MUL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3233, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3234, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3235, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3237, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3238, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3239, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3240, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3242, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3248, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3249, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3250, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3252, ZEND_MUL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3268, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3269, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3270, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3271, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3272, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3273, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3274, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3275, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3276, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3280, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3281, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3282, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3283, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3284, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3285, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3286, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3287, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3288, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3289, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3290, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3291, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3295, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3296, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3297, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3313, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3314, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3315, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3316, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3317, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3318, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3319, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3320, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3321, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3325, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3326, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3327, ZEND_IS_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3343, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3344, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3345, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3346, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3347, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3348, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3349, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3350, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3351, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3355, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3356, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3357, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3358, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3359, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3360, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3361, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3362, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3363, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3364, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3365, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3366, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3370, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3371, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3372, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3388, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3389, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3390, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3391, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3392, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3393, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3394, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3395, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3396, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3400, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3401, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3402, ZEND_IS_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3418, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3419, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3420, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3421, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3422, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3423, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3424, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3425, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3426, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3430, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3431, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3432, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3433, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3434, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3435, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3436, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3437, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3438, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3439, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3440, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3441, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3445, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3446, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3447, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3463, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3464, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3465, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3466, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3467, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3468, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3469, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3470, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3471, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3475, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3476, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3477, ZEND_IS_NOT_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3493, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3494, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3495, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3496, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3497, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3498, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3499, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3500, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3501, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3505, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3506, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3507, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3508, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3509, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3510, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3511, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3512, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3513, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3514, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3515, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3516, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3520, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3521, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3522, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3538, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3539, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3540, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3541, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3542, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3543, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3544, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3545, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3546, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3550, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3551, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3552, ZEND_IS_NOT_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3556, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV) \
	_(3557, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3558, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3559, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV) \
	_(3560, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3561, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3565, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV) \
	_(3566, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3567, ZEND_IS_SMALLER_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3568, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST) \
	_(3569, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3570, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3571, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3572, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3573, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3574, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3575, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3576, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3580, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3581, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3582, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3583, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST) \
	_(3584, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3585, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3586, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3587, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3588, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3589, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3590, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3591, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3595, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3596, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3597, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3613, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST) \
	_(3614, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3615, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3616, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3617, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3618, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3619, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3620, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3621, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3625, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3626, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3627, ZEND_IS_SMALLER_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3631, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3632, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3633, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3634, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3635, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3636, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3640, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3641, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3642, ZEND_IS_SMALLER_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3643, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3644, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3645, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3646, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3647, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3648, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3649, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3650, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3651, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3655, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3656, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3657, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3658, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3659, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3660, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3661, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3662, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3663, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3664, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3665, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3666, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3670, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3671, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3672, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3688, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3689, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3690, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3691, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3692, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3693, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3694, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3695, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3696, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3700, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3701, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3702, ZEND_IS_SMALLER_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3706, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV) \
	_(3707, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3708, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3709, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV) \
	_(3710, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3711, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3715, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV) \
	_(3716, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3717, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3718, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3719, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3720, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3721, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3722, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3723, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3724, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3725, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3726, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3730, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3731, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3732, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3733, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3734, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3735, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3736, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3737, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3738, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3739, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3740, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3741, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3745, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3746, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3747, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3763, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST) \
	_(3764, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3765, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3766, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3767, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3768, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3769, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3770, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3771, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3775, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV) \
	_(3776, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3777, ZEND_IS_SMALLER_OR_EQUAL_LONG_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3781, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3782, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3783, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3784, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3785, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3786, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3790, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV) \
	_(3791, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPZ) \
	_(3792, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_CONST_TMPVARCV_JMPNZ) \
	_(3793, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3794, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3795, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3796, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3797, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3798, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3799, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3800, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3801, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3805, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3806, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3807, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3808, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3809, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3810, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3811, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3812, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3813, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3814, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3815, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3816, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3820, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3821, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3822, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3838, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST) \
	_(3839, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPZ) \
	_(3840, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_CONST_JMPNZ) \
	_(3841, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3842, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3843, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3844, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3845, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3846, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3850, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV) \
	_(3851, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPZ) \
	_(3852, ZEND_IS_SMALLER_OR_EQUAL_DOUBLE_SPEC_TMPVARCV_TMPVARCV_JMPNZ) \
	_(3853, ZEND_PRE_INC_LONG_NO_OVERFLOW_SPEC_CV_RETVAL_UNUSED) \
	_(3854, ZEND_PRE_INC_LONG_NO_OVERFLOW_SPEC_CV_RETVAL_USED) \
	_(3855, ZEND_PRE_INC_LONG_SPEC_CV_RETVAL_UNUSED) \
	_(3856, ZEND_PRE_INC_LONG_SPEC_CV_RETVAL_USED) \
	_(3857, ZEND_PRE_INC_LONG_OR_DOUBLE_SPEC_CV_RETVAL_UNUSED) \
	_(3858, ZEND_PRE_INC_LONG_OR_DOUBLE_SPEC_CV_RETVAL_USED) \
	_(3859, ZEND_PRE_DEC_LONG_NO_OVERFLOW_SPEC_CV_RETVAL_UNUSED) \
	_(3860, ZEND_PRE_DEC_LONG_NO_OVERFLOW_SPEC_CV_RETVAL_USED) \
	_(3861, ZEND_PRE_DEC_LONG_SPEC_CV_RETVAL_UNUSED) \
	_(3862, ZEND_PRE_DEC_LONG_SPEC_CV_RETVAL_USED) \
	_(3863, ZEND_PRE_DEC_LONG_OR_DOUBLE_SPEC_CV_RETVAL_UNUSED) \
	_(3864, ZEND_PRE_DEC_LONG_OR_DOUBLE_SPEC_CV_RETVAL_USED) \
	_(3865, ZEND_POST_INC_LONG_NO_OVERFLOW_SPEC_CV) \
	_(3866, ZEND_POST_INC_LONG_SPEC_CV) \
	_(3867, ZEND_POST_INC_LONG_OR_DOUBLE_SPEC_CV) \
	_(3868, ZEND_POST_DEC_LONG_NO_OVERFLOW_SPEC_CV) \
	_(3869, ZEND_POST_DEC_LONG_SPEC_CV) \
	_(3870, ZEND_POST_DEC_LONG_OR_DOUBLE_SPEC_CV) \
	_(3871, ZEND_QM_ASSIGN_DOUBLE_SPEC_CONST) \
	_(3872, ZEND_QM_ASSIGN_DOUBLE_SPEC_TMPVARCV) \
	_(3873, ZEND_QM_ASSIGN_DOUBLE_SPEC_TMPVARCV) \
	_(3875, ZEND_QM_ASSIGN_DOUBLE_SPEC_TMPVARCV) \
	_(3876, ZEND_QM_ASSIGN_NOREF_SPEC_CONST) \
	_(3877, ZEND_QM_ASSIGN_NOREF_SPEC_TMPVARCV) \
	_(3878, ZEND_QM_ASSIGN_NOREF_SPEC_TMPVARCV) \
	_(3880, ZEND_QM_ASSIGN_NOREF_SPEC_TMPVARCV) \
	_(3882, ZEND_FETCH_DIM_R_INDEX_SPEC_CONST_TMPVARCV) \
	_(3883, ZEND_FETCH_DIM_R_INDEX_SPEC_CONST_TMPVARCV) \
	_(3885, ZEND_FETCH_DIM_R_INDEX_SPEC_CONST_TMPVARCV) \
	_(3886, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_CONST) \
	_(3887, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3888, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3890, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3891, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_CONST) \
	_(3892, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3893, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3895, ZEND_FETCH_DIM_R_INDEX_SPEC_TMPVAR_TMPVARCV) \
	_(3901, ZEND_FETCH_DIM_R_INDEX_SPEC_CV_CONST) \
	_(3902, ZEND_FETCH_DIM_R_INDEX_SPEC_CV_TMPVARCV) \
	_(3903, ZEND_FETCH_DIM_R_INDEX_SPEC_CV_TMPVARCV) \
	_(3905, ZEND_FETCH_DIM_R_INDEX_SPEC_CV_TMPVARCV) \
	_(3908, ZEND_SEND_VAR_SIMPLE_SPEC_VAR) \
	_(3910, ZEND_SEND_VAR_SIMPLE_SPEC_CV) \
	_(3913, ZEND_SEND_VAR_EX_SIMPLE_SPEC_VAR) \
	_(3915, ZEND_SEND_VAR_EX_SIMPLE_SPEC_CV) \
	_(3916, ZEND_SEND_VAL_SIMPLE_SPEC_CONST) \
	_(3917, ZEND_SEND_VAL_EX_SIMPLE_SPEC_CONST) \
	_(3918, ZEND_FE_FETCH_R_SIMPLE_SPEC_VAR_CV_RETVAL_UNUSED) \
	_(3919, ZEND_FE_FETCH_R_SIMPLE_SPEC_VAR_CV_RETVAL_USED) \
	_(3919+1, ZEND_NULL)
